<?php

/**
 * @copyright (C) 2000 - 2014 Weaver Co.Ltd
 * @package   eoffice8.0
 * @name      webroot/E-mobile/App/Calendar/CalendarProxy.php
 * @function  日程代理类       
 * @version   1.0 
 * @author    lizj
 */
include_once("api/calendar.class.php");

class CalendarProxy {

    private $_userId;
    private $_sessionKey;
    private static $_calendar;

    public function __construct() {
        global $_lang;
        $sessionstr = request_var("sessionkey");
        $this->_sessionKey = $sessionstr;
        $strexplode = explode("_", $sessionstr);
        $this->_userId = $userId = $strexplode[1];
        if (!CheckSessionKeys($strexplode[0])) {
            echo $_lang["e_calendar_login_again"];
            exit;
        }
        if (!self::$_calendar) {
            self::$_calendar = new calendar(array('user_id' => $userId));
        }
    }

    public function viewUpdate() {
        global $_lang;
        $sessionstr =   $this->_sessionKey ;
        if (!CheckMenuPriv($this->_userId, "calendar")) {
            echo $_lang["e_calendar_no_menu_auth"];
            exit;
        }

        include_once(INCLUDE_APP_PATH . 'Calendar/View/ControlCenterView.php');
    }

    public function myBrach() {
        $sessionstr =   $this->_sessionKey ;
        $branchUser = self::$_calendar->getDefaultAttention($this->_userId);
        echo json_encode($branchUser);
    }

    public function myAttention() {
        $sessionstr =   $this->_sessionKey ;
        $attentionUser = self::$_calendar->getHadAttention($this->_userId);
        echo json_encode($attentionUser);
    }

    public function getHasCalendarDate() {
        $sessionstr =   $this->_sessionKey ;
        $userId = request_var('user_id', '');
        $month = request_var('month');
        $year = request_var('year');
        $startDate = $year . '-' . $month . '-' . '01 00:00:00';
        if ($month == 12) {
            $year = intval($year) + 1;
            $month = '01';
        } else {
            $month = intval($month) + 1;
            $month = $month < 10 ? '0' . $month : $month;
        }
        $endDate = $year . '-' . $month . '-' . '01 00:00:00';
        if (!$userId) {
            $calendars = self::$_calendar->myCalendarList('myAll', $startDate, $endDate, false, false, ' ORDER BY CAL_BEGIN ASC');
        } else {
            $calendars = self::$_calendar->myCalendarList(false, $startDate, $endDate, $userId, false, ' ORDER BY CAL_BEGIN ASC');
        }
        $dealCalendar = array();
        if ($calendars) {
            foreach ($calendars as $calendar) {
                $begin = explode(' ', $calendar['CAL_BEGIN']);
                $end = explode(' ', $calendar['CAL_END']);
                if ($begin[0] < $end[0]) {
                    $type = $end[1] == '00:00:00' ? true : false;
                    $dates = $this->getDateArray($begin[0], $end[0], $type);
                    $dealCalendar = array_merge($dealCalendar, $dates);
                } else {
                    if (!in_array($begin[0], $dealCalendar)) {
                        $dealCalendar[] = $begin[0];
                    }
                }
            }
        }
        echo json_encode($dealCalendar);
    }

    private function getDateArray($beginDate, $endDate, $type) {
        $sessionstr =   $this->_sessionKey ;
        for ($i = 0; strtotime($beginDate . '+' . $i . ' days') <= strtotime($endDate) && $i < 365; $i++) {
            $time = strtotime($beginDate . '+' . $i . ' days');
            $date[] = date('Y-m-d', $time);
        }
        if ($type) {
            array_pop($date);
        }
        return $date;
    }

    public function getCalendarByDate() {
        global $_lang;
        $sessionstr =   $this->_sessionKey ;
        $userId = request_var('user_id', '');
        $month = request_var('month');
        $year = request_var('year');
        $day = request_var('day');
        $startDate = $year . '-' . $month . '-' . $day . ' 00:00:00';
        $days = $this->getMonthLastDay($month, $year);
        if ($day == $days) {
            if ($month == 12) {
                $month = '01';
                $year = $year + 1;
            } else {
                $month = intval($month) + 1;
                $month = $month < 10 ? '0' . $month : $month;
            }
            $day = '01';
        } else {
            $day = $day + 1;
            $day = $day < 10 ? '0' . $day : $day;
        }
        $endDate = $year . '-' . $month . '-' . $day . ' 00:00:00';
        if (!$userId) {
            $calendars = self::$_calendar->myCalendarList('myAll', $startDate, $endDate, false, false, ' ORDER BY CAL_BEGIN ASC');
        } else {
            $calendars = self::$_calendar->myCalendarList(false, $startDate, $endDate, $userId, false, ' ORDER BY CAL_BEGIN ASC');
        }
        $dealCalendar = array();
        if ($calendars) {
            foreach ($calendars as $calendar) {
                $calendar['CAL_BEGIN'] = date($_lang['e_calendar_date_format'], strtotime($calendar['CAL_BEGIN']));
                $calendar['CAL_END'] = date($_lang['e_calendar_date_format'], strtotime($calendar['CAL_END']));
                $beginArr = explode(' ', $calendar['CAL_BEGIN']);
                $endArr = explode(' ', $calendar['CAL_END']);
                if ($beginArr[0] == $endArr[0]) {
                    $calendar['CAL_BEGIN'] = $beginArr[1];
                    $calendar['CAL_END'] = $endArr[1];
                }
                $calendar['USER_AVATAR'] = $this->getUserAvatar($calendar['USER_ID']);
                $dealCalendar[] = $calendar;
            }
        }
        echo json_encode($dealCalendar);
    }

    private function getMonthLastDay($month, $year) {
        $sessionstr =   $this->_sessionKey ;
        switch ($month) {
            case 4 :
            case 6 :
            case 9 :
            case 11 :
                $days = 30;
                break;
            case 2 :
                if ($year % 4 == 0) {
                    if ($year % 100 == 0) {
                        $days = $year % 400 == 0 ? 29 : 28;
                    } else {
                        $days = 29;
                    }
                } else {
                    $days = 28;
                }
                break;
            default :
                $days = 31;
                break;
        }

        return $days;
    }

    public function getAllCalendar() {
        global $_lang;
        $sessionstr =   $this->_sessionKey ;
        $page = request_var('page', 1);
        $userId = request_var('user_id', '');
        $start = (intval($page) - 1) * 10;
        $limit = ' LIMIT ' . $start . ',10';
        if (!$userId) {
            $calendars = self::$_calendar->myCalendarList('myAll', false, false, false, false, ' ORDER BY CAL_BEGIN DESC', $limit);
        } else {
            $calendars = self::$_calendar->myCalendarList(false, false, false, $userId, false, ' ORDER BY CAL_BEGIN DESC', $limit);
        }
        $dealCalendar = array();
        if ($calendars) {
            foreach ($calendars as $calendar) {
                $calendar['CAL_BEGIN'] = date($_lang['e_calendar_date_format'], strtotime($calendar['CAL_BEGIN']));
                $calendar['CAL_END'] = date($_lang['e_calendar_date_format'], strtotime($calendar['CAL_END']));
                $calendar['USER_AVATAR'] = $this->getUserAvatar($calendar['USER_ID']);
                $dealCalendar[] = $calendar;
            }
        }
        echo json_encode($dealCalendar);
    }

    /**
     * 获取个人头像路径
     * @param type $ATTACH_PATH
     * @return type
     */
    public function getUserAvatar($userId) {
        global $connection, $ATTACH_PATH;
        $userId = SecurityFilter($userId);
        $sessionstr =   $this->_sessionKey ;
        $sql = "SELECT AVATAR_TYPE FROM user WHERE USER_ID='" . $userId . "'";
        $rs = exequery($connection, $sql);
        $row = mysql_fetch_array($rs);
        $avatarType = $row['AVATAR_TYPE'];
        if (!$avatarType) {
            $avatarType = ".png"; //默认值为png
        }

        $userAvatar = "/attachment/personal/" . $userId . "/avatar_50" . $avatarType;
        if (!file_exists($ATTACH_PATH . "personal/" . $userId . "/avatar_50" . $avatarType)) {
            return '/attachment/personal/noimage_50.png';
        }
        return $userAvatar;
    }

    public function detail() {
        global $_lang;
        $calId = intval(request_var("calId"));
        $sessionstr =   $this->_sessionKey ;
        $dataInfor = self::$_calendar->caleGetSingleData("calendar", " AND CAL_ID='" . $calId . "'");
        $dataInfor['CAL_LEVEL'] = $dataInfor['CAL_LEVEL'] == 1 ? $_lang["calendar_level_normal"] : ($dataInfor['CAL_LEVEL'] == 2 ? $_lang["calendar_level_import"] : $_lang["calendar_level_urgency"]);
        if ($dataInfor["LABELSTR"]) {
            include_once("api/labels.class.php");
            $labelsApi = new labels();
            $labelArray = explode(",", $dataInfor["LABELSTR"]);
            $labelInfo = '';
            foreach ($labelArray as $label) {
                $labelInfor = $labelsApi->labelSearchSingleData("labels", " AND LAB_ID='" . $label . "'");
                if ($labelInfor["LAB_NAME"]) {
                    $labelInfo .= $labelInfor["LAB_NAME"] . ',';
                }
            }
            $dataInfor["LABELSTR"] = $labelInfo;
        }
        $dataInfor["CAL_REMIND"] = $dataInfor["CAL_REMIND"] == 1 ? $dataInfor["CAL_SMS_COUNT"] . " " . $_lang["calendar_hour"] : $_lang['e_calendar_no_sms_tip'];
        $dataInfor["CAL_BEGIN"] = substr($dataInfor["CAL_BEGIN"], 0, -3);
        $dataInfor["CAL_END"] = substr($dataInfor["CAL_END"], 0, -3);
        $dataInfor["USER_NAME"] = getUserNameNew($dataInfor["USER_ID"]);
        $dataInfor["SHARE_USER"] = getUsernameStr($dataInfor["SHARE_USER"]);
        $dataInfor["RECEIVE_USER"] = getUsernameStr($dataInfor["RECEIVE_USER"]);
        $dataInfor['CAL_WHILE_BEGIN'] = substr($dataInfor['CAL_WHILE_BEGIN'], 0, -9);
        if ($dataInfor['CAL_WHILE_BEGIN'] == "0000-00-00") {
            $dataInfor['CAL_WHILE_BEGIN'] = date("Y-m-d");
        }
        $dataInfor['CAL_WHILE_END'] = substr($dataInfor['CAL_WHILE_END'], 0, -9);
        if ($dataInfor['CAL_WHILE_END'] == "0000-00-00") {
            $dataInfor['CAL_WHILE_END'] = date("Y-m-d");
        }
        echo json_encode($dataInfor);
    }

    public function create() {
        global $_lang;
        $userid = $this->_userId;
        $sessionstr = $this->_sessionKey ;
        $userName = getUserNameNew($userid);
        $currentUserId = $userid . ',';
        $date = request_var('date');
        $flag = request_var('flag');
        include_once(INCLUDE_APP_PATH . 'Calendar/View/CreateCalendarView.php');
    }

    public function createDo() {
        global $connection, $_lang;
        $sessionstr = $this->_sessionKey;
        $strexplode = explode("_", $sessionstr);
        $userid = $strexplode[1];
        $userarray = GetCurrUserPriv($userid);
        $USER_FUNC_ID_STR = $userarray["FUNC_ID_STR"];

        $enddate = request_var("enddate");
        $endtime = request_var("endtime");
        $curdate = date("Y-m-d H:i:s", time());
        $calbegin = request_var('begindate') . " " . request_var('begintime') . ":00";
        if ($endtime == '24:00') {
            $enddate = date("Y-m-d", strtotime($enddate) + 24 * 60 * 60);
            $endtime = "00:00";
        }
        $calend = $enddate . " " . $endtime . ":00";
        $shareuser = request_var('shareUser');
        $receiveUser = request_var('receiveUser');
        $contents = request_var('contents');
        $dataInfor = array(
            'USER_ID' => $this->_userId,
            'SHARE_USER' => $shareuser,
            'RECEIVE_USER' => $receiveUser,
            'CAL_LEVEL' => request_var('level'),
            'CAL_TYPE' => 0,
            'CAL_BEGIN' => $calbegin,
            'CAL_END' => $calend,
            'CREATE_TIME' => $curdate,
            'CAL_CONTENT' => $contents,
            'CAL_WHILE_TYPE' => 0,
            'CAL_WHILE_BEGIN' => '0000-00-00 00:00:00',
            'CAL_WHILE_END' => '0000-00-00 00:00:00',
            'CAL_IS_NEVER' => 0,
            'CAL_EACH_WHEEL' => 0,
            'CAL_STR_WEEK' => 0,
            'CAL_REMIND' => request_var('cal_remind'),
            'CAL_SMS_TYPE' => 0,
            'CAL_SMS_COUNT' => request_var('cal_sms_count'),
            'LABELSTR' => ''
        );
        $TABLE_ID = self::$_calendar->createNewData($dataInfor, 'calendar');
        //播报
        AddBroacastLog($userid, "CALENDAR", "CAL_ID", $TABLE_ID, "CAL_CONTENT", "new");
        //消息
        $SMS_CONTENT = $_lang["e_calendar_remind"] . "：[" . $calbegin . "] " . $_lang["e_calendar_start"] . $contents;
        sendSms($userid, $shareuser, $SMS_CONTENT, '1', '28', 'CALENDAR', $TABLE_ID, '', '', '', $calbegin);
        sendSms($userid, $receiveUser, $SMS_CONTENT, '1', '28', 'CALENDAR', $TABLE_ID, '', '', '', $calbegin);
        if ($TABLE_ID) {
            echo 1;
        } else {
            echo 0;
        }
    }

    public function view() {
        global $_lang;
        $sessionstr =   $this->_sessionKey ;
        $calId = intval(request_var("detailid"));
        $dataInfor = self::$_calendar->caleGetSingleData("calendar", " AND CAL_ID='" . $calId . "'");
        $dataInfor['CAL_LEVEL'] = $dataInfor['CAL_LEVEL'] == 1 ? $_lang["calendar_level_normal"] : ($dataInfor['CAL_LEVEL'] == 2 ? $_lang["calendar_level_import"] : $_lang["calendar_level_urgency"]);
        if ($dataInfor["LABELSTR"]) {
            include_once("api/labels.class.php");
            $labelsApi = new labels();
            $labelArray = explode(",", $dataInfor["LABELSTR"]);
            $labelInfo = '';
            foreach ($labelArray as $label) {
                $labelInfor = $labelsApi->labelSearchSingleData("labels", " AND LAB_ID='" . $label . "'");
                if ($labelInfor["LAB_NAME"]) {
                    $labelInfo .= $labelInfor["LAB_NAME"] . ',';
                }
            }
            $dataInfor["LABELSTR"] = $labelInfo;
        }
        $dataInfor["CAL_REMIND"] = $dataInfor["CAL_REMIND"] == 1 ? $dataInfor["CAL_SMS_COUNT"] . " " . $_lang["calendar_hour"] : $_lang['e_calendar_no_sms_tip'];
        $dataInfor["CAL_BEGIN"] = substr($dataInfor["CAL_BEGIN"], 0, -3);
        $dataInfor["CAL_END"] = substr($dataInfor["CAL_END"], 0, -3);
        $dataInfor["USER_NAME"] = getUserNameNew($dataInfor["USER_ID"]);
        $dataInfor["SHARE_USER"] = getUsernameStr($dataInfor["SHARE_USER"]);
        $dataInfor["RECEIVE_USER"] = getUsernameStr($dataInfor["RECEIVE_USER"]);
        $dataInfor['CAL_WHILE_BEGIN'] = substr($dataInfor['CAL_WHILE_BEGIN'], 0, -9);
        if ($dataInfor['CAL_WHILE_BEGIN'] == "0000-00-00") {
            $dataInfor['CAL_WHILE_BEGIN'] = date("Y-m-d");
        }
        $dataInfor['CAL_WHILE_END'] = substr($dataInfor['CAL_WHILE_END'], 0, -9);
        if ($dataInfor['CAL_WHILE_END'] == "0000-00-00") {
            $dataInfor['CAL_WHILE_END'] = date("Y-m-d");
        }
       // echo json_encode($dataInfor);
        
        include_once(INCLUDE_APP_PATH . 'Calendar/View/pushSmsCalendarView.php');
        
    }

}
