<?php

class JSSDK {

    private $appId;
    private $appSecret;
    private $appDomin;
    private $access_token;
    private $comefrom;

    public function __construct($appId, $appSecret, $appDomin, $access_token, $comefrom) {
        $this->appId = $appId;
        $this->appSecret = $appSecret;
        $this->appDomin = $appDomin;
        $this->access_token = $access_token;
        $this->comefrom = $comefrom;
    }

    public function getSignPackage() {

        if ($this->comefrom == "weixin") {
            $jsapiTicket = $this->getJsApiTicket();
        } else {
            $jsapiTicket = $this->getQyJsApiTicket();
        }
 
        // 注意 URL 一定要动态获取，不能 hardcode.
//        $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
//        $url = "$protocol$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
        
        $url = $this->appDomin.$_SERVER["REQUEST_URI"];

        $timestamp = time();
        $nonceStr = $this->createNonceStr();

        // 这里参数的顺序要按照 key 值 ASCII 码升序排序
        $string = "jsapi_ticket=$jsapiTicket&noncestr=$nonceStr&timestamp=$timestamp&url=$url";

        $signature = sha1($string);

        $signPackage = array(
            "appId" => $this->appId,
            "nonceStr" => $nonceStr,
            "timestamp" => $timestamp,
            "url" => $url,
            "signature" => $signature,
            "rawString" => $string,
            'appDomin' => $this->appDomin
        );
        return $signPackage;
    }

    private function createNonceStr($length = 16) {
        $chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
        $str = "";
        for ($i = 0; $i < $length; $i++) {
            $str .= substr($chars, mt_rand(0, strlen($chars) - 1), 1);
        }
        return $str;
    }

    private function getJsApiTicket() {
        $accessToken = $this->access_token;
        if (!$accessToken) {
            return false;
        }
        $url = "https://api.weixin.qq.com/cgi-bin/ticket/getticket?type=jsapi&access_token=$accessToken";
        $res = json_decode($this->httpGet($url));
        $ticket = $res->ticket;

        return $ticket;
    }

    private function getQyJsApiTicket() {
        $accessToken = $this->access_token;
        if (!$accessToken) {
            return false;
        }
        $url = "https://qyapi.weixin.qq.com/cgi-bin/get_jsapi_ticket?access_token=$accessToken";
        $res = json_decode($this->httpGet($url));
        $ticket = $res->ticket;

        return $ticket;
    }

    private function httpGet($url) {
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_TIMEOUT, 500);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($curl, CURLOPT_URL, $url);

        $res = curl_exec($curl);
        curl_close($curl);

        return $res;
    }

}
