<?php
/**
 * @copyright  (C) 2014 - 2015 Weaver Co.Ltd
 * @package    eoffice9.0
 * @name       api/IncomeExpend.class.php
 * @function   收支管理类
 * @author     lizhijun
 * @date       2015-3-27
 */
class IncomeExpend {
    public $pageSize;
    public $userId;
    public $deptId;
    public $privId;
    public $userSelect = false;
    private $_currentTime;
    public function __construct() {
        $this->_currentTime = time();
    }
    /**
     * 获取方案类型列表
     * @return type
     */
    public function planTypeLists(){
        $query  = 'SELECT TYPE_ID,TYPE_NAME FROM payment_plan_type';
        $lists = $this->_getSqlRows($query);
        return $lists;
    }
    /**
     * 获取方案类型详情信息
     * @param type $typeId
     * @return type
     */
    public function planTypeDetail($typeId){
        $query = 'SELECT * FROM payment_plan_type WHERE TYPE_ID='.SecurityFilter($typeId);
        $detail = $this->_getSqlRow($query);
        return $detail;
    }
    /**
     * 添加方案类型
     * @param type $data
     * @return type
     */
    public function addPlanType($data = array()){
        return $this->_executeQuery('INSERT', $data,'payment_plan_type');
    }
    /**
     * 更新方案类型
     * @param type $data
     * @param type $condition
     * @return type
     */
    public function updatePlanType($data = array(),$condition = array()){
        return $this->_executeQuery('UPDATE', $data,'payment_plan_type',true,$condition);
    }
    /**
     * 删除方案类型
     * @global type $connection
     * @param type $typeId
     * @return boolean
     */
    public function deletePlanType($typeId){
        global $connection;
        if(!$typeId){
            return false;
        }
        $query = 'DELETE FROM payment_plan_type WHERE TYPE_ID='.SecurityFilter($typeId);
        $result = exequery($connection,$query);
        return $result;
    }
    /**
     * 判断某类型想是否有方案
     * @param type $typeId
     * @return boolean
     */
    public function hasPlanOfType($typeId){
        $query = 'SELECT * FROM payment_plan WHERE PLAN_TYPE='.SecurityFilter($typeId);
        $lists = $this->_getSqlRows($query);
        $size = sizeof($lists);
        if($size > 0){
            return true;
        }
        return false;
    }
    /**
     * 获取最后一个方案编码
     * @return boolean
     */
    public function getLastPlanCode(){
        $query = "SELECT PLAN_ID FROM payment_plan ORDER BY PLAN_ID DESC LIMIT 0,1";
        $row = $this->_getSqlRow($query);
        if($row){
            return $row['PLAN_ID'];
        }
        return false;
    }
    /**
     * 添加方案
     * @global type $connection
     * @param type $data
     * @param type $dataSub
     * @return boolean
     */
    public function addPlan($data = array(),$dataSub = array()){
        $id = $this->_executeQuery('INSERT', $data,'payment_plan');
        if($id){
            $dataSub['PLAN_ID'] = $id;
            if($this->_executeQuery('INSERT', $dataSub,'payment_plan_sub',false)){
                return $id;
            }
            global $connection;
            $query = 'DELETE FROM payment_plan WHERE PLAN_ID='.SecurityFilter($id);
            exequery($connection,$query);
        }
        return false;
    }
    /**
     * 更新方案
     * @param type $data
     * @param type $dataSub
     * @param type $planId
     * @return boolean
     */
    public function updatePlan($data,$dataSub,$planId){
        if(!$planId){
            return false;
        }
        $result1 = $this->_executeQuery('UPDATE', $data,'payment_plan',true,array('PLAN_ID' => $planId));
        $result2 = $this->_executeQuery('UPDATE', $dataSub,'payment_plan_sub',true,array('PLAN_ID' => $planId));
        if($result1 && $result2){
            return true;
        }
        return false;
    }
    /**
     * 销毁方案
     * @global type $connection
     * @param type $id
     * @param type $destoryType
     * @return boolean
     */
    public function destoryPlan($id,$destoryType){
        global $connection;
        if(!$id){
            return false;
        }
        if($destoryType == 'batch'){
            $query  = 'DELETE FROM payment_plan WHERE PLAN_ID IN ('.SecurityFilter($id).')';
            $query1 = 'DELETE FROM payment_plan_sub WHERE PLAN_ID IN ('.SecurityFilter($id).')';
        }else{
            $query  = 'DELETE FROM payment_plan WHERE PLAN_ID='.SecurityFilter($id);
            $query1 = 'DELETE FROM payment_plan_sub WHERE PLAN_ID='.SecurityFilter($id);
        }
        if(exequery($connection,$query) && exequery($connection,$query1)){
            return true;
        }
        return false;
    }
	public function deleteRecordByPlanId($planId, $destoryType)
	{	
        if(!$planId){
            return false;
        }
		
        if($destoryType == 'batch'){
			foreach(explode(',', $planId) as $id){
				$this->_deleteRecordByPlanId($id);
			}
		} else {
			$this->_deleteRecordByPlanId($planId);
		}
		
		return true;
	}
	private function _deleteRecordByPlanId($planId)
	{
		global $connection;
		$query = "SELECT * FROM payment_records WHERE PLAN_ID = " . SecurityFilter($planId);
		$rows = $this->_getSqlRows($query);
		if($rows){
			foreach($rows as $row){
				$in     = $row['REVENUE'];
				$out    = $row['EXPENSE'];
				$year   = $row['YEAR'];
				$month  = $row['MONTH'];
				$sql = 'SELECT * FROM payment_stat WHERE `YEAR`='.SecurityFilter($year).' AND `MONTH`='.SecurityFilter($month);
				$result = $this->_getSqlRow($sql);
				$in2 = $result['IN'] - $in;
				$out2 = $result['OUT'] - $out;
				$times = $result['times'] - 1;
				$data = array(
                    'IN'    => $in2,
                    'OUT'   => $out2,
                    'TIMES' => $times
                );
				$where = array(
                    'year'  => $year,
                    'month' => $month
                );
				$query  = 'DELETE FROM payment_records WHERE RECORD_ID=' . SecurityFilter($row['RECORD_ID']);
				$query1 = 'DELETE FROM payment_records_sub WHERE RECORD_ID=' . SecurityFilter($row['RECORD_ID']);
				exequery($connection,$query);
				exequery($connection,$query1);
				$this->_executeUpdate($data,'payment_stat',$where);
			}
		}
	}
    /**
     * 删除方案
     * @global type $connection
     * @param type $id
     * @param type $deleteType
     * @return boolean
     */
    public function deletePlan($id,$deleteType){
        if(!$id){
            return false;
        }
        if($deleteType == 'batch'){
            global $connection;
            $query = 'UPDATE `payment_plan` SET STATUS=0 WHERE PLAN_ID IN('.SecurityFilter($id).')';
            return exequery($connection,$query);
        }
        $data = array('STATUS' => 0);
        return $this->_executeQuery('UPDATE', $data,'payment_plan',true,array('PLAN_ID' => $id));
    }
    /**
     * 删除附件
     * @param type $planId
     * @param type $attachId
     * @param type $attachName
     * @return boolean
     */
    public function deleteAttachment($planId, $attachId,$attachName){
        if(!$planId){
            return false;
        }
        $data = array('ATTACHMENT_ID' => $attachId,'ATTACHMENT_NAME' => $attachName);
        return $this->_executeQuery('UPDATE', $data,'payment_plan_sub',true,array('PLAN_ID' => $planId));
    }
    /**
     * 检查方案状态
     * @param type $id
     * @return boolean
     */
    public function checkPlanState($id){
        $query = 'SELECT PLAN_ID FROM payment_plan WHERE PLAN_ID IN('.SecurityFilter($id).') AND PLAN_STATE=1';
        $row = $this->_getSqlRow($query);
        if($row){
            return $row['PLAN_ID'];
        }

        return false;
    }
   /**
    * 启动方案
    * @global type $connection
    * @param type $id
    * @param type $startType
    * @return boolean
    */
    public function startPlan($id,$startType){
        if(!$id){
            return false;
        }
        if($startType == 'batch'){
            global $connection;
            $query = 'UPDATE `payment_plan` SET START_TIME='.time().',PLAN_STATE=1,IS_START=1,END_TIME=0 WHERE PLAN_ID IN('.SecurityFilter($id).') AND PLAN_STATE !=1';
            return exequery($connection,$query);
        }else{
            $data = array('PLAN_STATE' => 1,'IS_START' => 1,'START_TIME' => time(),'END_TIME' => 0);
            return $this->_executeQuery('UPDATE', $data,'payment_plan',true,array('PLAN_ID' => $id));
        }
    }
    /**
     * 结束方案
     * @global type $connection
     * @param type $id
     * @param type $endType
     * @return boolean
     */
    public function endPlan($id,$endType){
        if(!$id){
            return false;
        }
        if($endType == 'batch'){
            global $connection;
            $query = 'UPDATE `payment_plan` SET END_TIME='.time().',PLAN_STATE=2,IS_START=0 WHERE PLAN_ID IN('.SecurityFilter($id).') AND PLAN_STATE =1';
            return exequery($connection,$query);
        }else{
            $data = array('PLAN_STATE' => 2,'IS_START' => 0,'END_TIME' => time());
            return $this->_executeQuery('UPDATE', $data,'payment_plan',true,array('PLAN_ID' => $id));
        }
    }
    /**
     * 恢复方案
     * @global type $connection
     * @param type $id
     * @param type $recoverType
     * @return boolean
     */
    public function recoverPlan($id,$recoverType){
        if(!$id){
            return false;
        }
        if($recoverType == 'batch'){
            global $connection;
            $query = 'UPDATE `payment_plan` SET STATUS=1 WHERE PLAN_ID IN('.SecurityFilter($id).')';
            return exequery($connection,$query);
        }else{
            $data = array('STATUS' => 1);
            return $this->_executeQuery('UPDATE', $data,'payment_plan',true,array('PLAN_ID' => $id));
        }
    }
    /**
     * 获取简单的方案列表
     * @param type $selectName
     * @param type $start
     * @param type $pageSize
     * @param type $condition
     * @param type $order
     * @return boolean
     */
    public function simplePlanLists($selectName = array(),$start=0,$pageSize=0,$condition = array(),$order = array()){
        if(!$this->userId){           
            return false;
        }
        $pageSize = $pageSize == 0 ? $this->pageSize : $pageSize;
        $limit = " LIMIT $start,$this->pageSize";
        $orderSql = '';
        if(!empty($order)){
            $orderSql  = ' ORDER BY ';
            foreach($order as $key => $value){
                $key    = strtoupper($key);
                $value  = strtoupper($value);
                $orderSql .= " $key $value,";
            }
            $orderSql  = substr($orderSql,0,strrpos($orderSql, ','));
        }
        $queryList = 'SELECT ';
        if(empty($selectName)){
            $queryList .= '*';
        }else{
            foreach ($selectName as $k => $v){
                $queryList .= "$v,";
            }
            $queryList  = substr($queryList,0,strrpos($queryList, ','));
        }
        $queryList .= ' FROM payment_plan WHERE 1=1 ';
        if($this->userId != 'admin'){
           $query .= " AND (CREATOR= '".SecurityFilter($this->userId)."' OR ALL_USER = 2 OR (FIND_IN_SET('".SecurityFilter($this->userId)."',USER_ID) OR FIND_IN_SET('".SecurityFilter($this->privId)."',ROAL_ID) OR FIND_IN_SET('".SecurityFilter($this->deptId)."',DEPT_ID))) ";
        }
        if(!empty($condition['like'])){ 
            $query .= ' AND (';
            foreach ($condition['like'] as $k => $v){
                $query .= $k .' LIKE '. "'%".SecurityFilter($v)."%' AND ";
            }
            $query  = substr($query,0,strrpos($query,'AND'));
            $query  .= ')';
        }
        if(!empty($condition['eq'])){
            $query .= ' AND (';
            foreach ($condition['eq'] as $k => $v){
                if(is_numeric($v)){
                    $query .= $k .' = '. SecurityFilter($v)." AND ";
                }else{
                    $query .= $k .' = '. "'".SecurityFilter($v) ."' AND ";
                }
            }
            $query  = substr($query,0,strrpos($query,'AND'));
            $query  .= ')';
        }
        if(!empty($condition['neq'])){
            $query .= ' AND (';
            foreach ($condition['neq'] as $k => $v){
                if(is_numeric($v)){
                    $query .= $k .' != '. SecurityFilter($v)." AND ";
                }else{
                    $query .= $k .' != '. "'" .SecurityFilter($v). "' AND ";
                }
            }
            $query  = substr($query,0,strrpos($query,'AND'));
            $query  .= ')';
        }
        if(!empty($condition['gt'])){
            $query .= ' AND (';
            foreach ($condition['gt'] as $k => $v){
                if(is_numeric($v)){
                    $query .= $k .' >= '. SecurityFilter($v)." AND ";
                }else{
                    $query .= $k .' >= '. "'".SecurityFilter($v)."' AND ";
                }
            }
            $query  = substr($query,0,strrpos($query,'AND'));
            $query  .= ')';
        }
        $countQuery = $query;
        if($orderSql){
            if(empty($condition['like'])){
                $query .= $orderSql;
            }
        }
        if($limit){
            $query .= $limit;
        }
        
        $queryID = 'SELECT PLAN_ID FROM payment_plan WHERE 1=1' . $query;
        $planIds  = $this->_getSqlRows($queryID);
        if($planIds){
            $inQuery = 'AND PLAN_ID IN (';
            foreach($planIds as $key => $value){
                $inQuery .= $value['PLAN_ID'].",";
            }
            $inQuery  = substr($inQuery,0,strrpos($inQuery,','));
            $inQuery  .= ')';
            $queryList .= $inQuery;            
            $lists  = $this->_getSqlRows($queryList . $orderSql);
            $_lists = array();
            foreach($lists as $key => $value){
                $value['RECORDS']       = $this->getOneRecordsSize($value['PLAN_ID']);
                $value['PLAN_ALL_NAME'] = $value['PLAN_NAME'];
                $value['PLAN_NAME']     = substrGB($value['PLAN_NAME'],12,'...');
                $value['START_TIME']    = date('Y/m/d',$value['START_TIME']);
                $value['END_TIME']      = date('Y/m/d',$value['END_TIME']);
                $_lists[] = $value;
            }
            if($condition['count'] == 1){
                $queryCount = 'SELECT count(*) as count FROM payment_plan WHERE 1=1 '.$countQuery;
                $planRow = $this->_getSqlRow($queryCount);
                $planCount = $planRow['count'];
                return array('totalCount' => $planCount,'list' => $_lists);
            }else{
                return $lists;
            }
        }
        return array('totalCount' => 0,'list' => '');
    }
    /**
     * 获取方案列表
     * @param type $selectName 
     * @param type $limitFlag
     * @param type $start
     * @param type $condition like=>array(),eq => array(),neq => array(),in => array(),count => 1/count=>0 
     * @param type $order name1 => asc,name2=> desc
     * @param type $group
     */
    public function planLists($selectName = array(),$limitFlag = false, $start=0,$condition = array(),$order = array(),$group = '',$link="AND"){
        $limit      = '';
        $orderSql   = '';
        $groupSql   = '';
        if($limitFlag){
            $limit .= " LIMIT $start,$this->pageSize";
        }
        if(!empty($order)){
            $orderSql  .= ' ORDER BY ';
            foreach($order as $key => $value){
                $key    = strtoupper($key);
                $value  = strtoupper($value);
                $orderSql .= " p.$key $value,";
            }
            $orderSql  = substr($orderSql,0,strrpos($orderSql, ','));
        }
        if($group != ''){
            $groupSql   = ' GROUP BY p.'.$group;
        }
        $planLists = $this->_planListSelect($selectName, $condition, $orderSql, $groupSql, $limit,$link);
        return $planLists;
    }
    /**
     * 获取方案信息
     * @param type $planId
     * @return boolean
     */
    public function planInfo($planId = 0){
        if($planId == 0){
            return false;
        }
        $query = "SELECT p.*,ps.ATTACHMENT_ID,ps.ATTACHMENT_NAME,ps.PLAN_DESCRIPTION,pt.TYPE_NAME,u.USER_ACCOUNTS,u.USER_NAME FROM payment_plan AS p "
                . " LEFT JOIN payment_plan_sub AS ps ON p.PLAN_ID = ps.PLAN_ID "
                . " LEFT JOIN payment_plan_type AS pt ON p.PLAN_TYPE = pt.TYPE_ID "
                . " LEFT JOIN user AS u ON p.CREATOR = u.USER_ID WHERE p.PLAN_ID=".SecurityFilter($planId);
        $planInfo = $this->_getSqlRow($query);
        return $planInfo;
    }
    /**
     * 添加收支记录
     * @global type $connection
     * @param type $data
     * @param type $subData
     * @param type $paymentData
     * @return boolean
     */
    public function addPaymentRecord($data,$subData,$paymentData){
        global $connection;
        $id = $this->_executeQuery('INSERT', $data,'payment_records');
        if($id){
            $subData['RECORD_ID'] = $id;
            if($this->_executeQuery('INSERT', $subData,'payment_records_sub',false)){
                if($this->_executeQuery('UPDATE', $paymentData,'payment_plan',true,array('PLAN_ID' => $data['PLAN_ID']))){
                    $statData['OUT']    = $data['EXPENSE'];
                    $statData['IN']     = $data['REVENUE'];
                    if($this->addStat($statData,$data['YEAR'],$data['MONTH'],$data['QUARTER'])){
                        return $id;
                    }
                    $paymentData['REAL_EXPENSE'] = $paymentData['REAL_EXPENSE'] - $data['EXPENSE'];
                    $paymentData['REAL_REVENUE'] = $paymentData['REAL_REVENUE'] - $data['REVENUE'];
                    $this->_executeQuery('UPDATE', $paymentData,'payment_plan',true,array('PLAN_ID' => $data['PLAN_ID']));
                    $query = 'DELETE FROM payment_records WHERE RECORD_ID='.SecurityFilter($id);
                    exequery($connection,$query);
                    $query = 'DELETE FROM payment_records_sub WHERE RECORD_ID='.SecurityFilter($id);
                    exequery($connection,$query);
                    return false;
                }
                $query = 'DELETE FROM payment_records WHERE RECORD_ID='.SecurityFilter($id);
                exequery($connection,$query);
                $query = 'DELETE FROM payment_records_sub WHERE RECORD_ID='.SecurityFilter($id);
                exequery($connection,$query);
                return false;
            }
            $query = 'DELETE FROM payment_records WHERE RECORD_ID='.SecurityFilter($id);
            exequery($connection,$query);
            return false;
        }
        return false;
    }
    /**
     * 添加统计信息
     * @param type $data
     * @return type
     */
    public function addStat($data,$year,$month,$quarter){
//        $year   = intval(date('Y'));
//        $month  = intval(date('m'));
//        $quarter = 0;
//        if($month == 1 || $month == 2 || $month == 3 ){
//            $quarter    = 1;
//        }else if($month == 4 || $month ==5 || $month ==6){
//            $quarter    = 2;
//        }else if($month == 7 || $month == 8 || $month == 9){
//            $quarter    = 3;
//        }else if($month == 10 || $month == 11 || $month == 12){
//            $quarter    = 4;
//        }
        $data['YEAR']       = $year;
        $data['QUARTER']    = $quarter;
        $data['MONTH']      = $month;
        $data['TIMES']      = 1;
        if($row = $this->_statExist($year,$month)){
            $data['IN']     += $row['IN'];
            $data['OUT']    += $row['OUT'];
            $data['TIMES']  += $row['TIMES'];
            return $this->_executeQuery('UPDATE', $data,'payment_stat',false,array('YEAR' => $year,'MONTH' => $month));
        }else{
            return $this->_executeQuery('INSERT', $data,'payment_stat',false);
        }
    }
    /**
     * 更新统计数据表
     * @param type $year
     * @param type $month
     * @return type
     */
    public function updateStat($data,$where){
        return $this->_executeQuery('UPDATE', $data,'payment_stat',false,$where);
    }
    /**
     * 判断某月统计信息是否存在
     * @param type $year
     * @param type $month
     * @return type
     */
    private function _statExist($year,$month){
        $query = "SELECT * FROM payment_stat WHERE YEAR=". SecurityFilter($year)." AND MONTH=".SecurityFilter($month);
        $row = $this->_getSqlRow($query);
        return $row;
    }
    /**
     * 根据年月获取记录
     * @param type $year
     * @param type $month
     * @return type
     */
    public function getRecords($year,$month){
        $query = "SELECT `EXPENSE`,`REVENUE` FROM payment_records WHERE YEAR=". SecurityFilter($year)." AND MONTH=".SecurityFilter($month);
        $rows = $this->_getSqlRows($query);
        return $rows;   
    }
    /**
     * 获取所有记录列表
     * @param type $condition
     * @param type $start
     * @param type $pageSize
     * @return boolean
     */
    public function allRecordList($condition = array(),$start = 0,$pageSize = 0){
        global $_lang;
        if(!$this->userId){           
            return false;
        }
        $pageSize = $pageSize == 0 ? $this->pageSize : $pageSize;
        $limit = " LIMIT $start,$this->pageSize";
        $query = "SELECT pr.RECORD_ID FROM payment_records AS pr LEFT JOIN payment_plan AS pp ON pr.PLAN_ID=pp.PLAN_ID WHERE pp.STATUS=1 AND pp.PLAN_STATE != 0 ";
        if($condition['beginTime']){
            $query .= ' AND pr.CREATE_TIME > '.SecurityFilter($condition['beginTime']);
        }
        if($condition['endTime']){
            $query .= ' AND pr.CREATE_TIME < '.SecurityFilter($condition['endTime']);
        }
        if($this->userId != 'admin'){
           $query .= " AND (pp.CREATOR= '$this->userId' OR pp.ALL_USER = 2 OR (FIND_IN_SET('".SecurityFilter($this->userId)."',pp.USER_ID) OR FIND_IN_SET('".SecurityFilter($this->privId)."',pp.ROAL_ID) OR FIND_IN_SET('".SecurityFilter($this->deptId)."',pp.DEPT_ID))) ";
        }
        $query .= ' ORDER BY pr.CREATE_TIME DESC '.$limit;
        $records = $this->_getSqlRows($query);
        $recordList = array();
        if($records){
            foreach ($records as $key => $value){
                $record = $this->getSimpleRecordInfo($value['RECORD_ID']);
                $createTime = date('Y-m-d H:i',$record['CREATE_TIME']);
                if(date('Y-m-d',$record['CREATE_TIME']) == date('Y-m-d')){
                    $time = substr($createTime, strrpos($createTime,' '));
                    $record['CREATE_TIME'] = $_lang["incomeexpend_today"].$time;
                    $record['TIME_TIP']   = 'success';
                }else if(date('Y-m-d',$record['CREATE_TIME']) == date("Y-m-d",strtotime("-1 day"))){
                    $time = substr($createTime, strrpos($createTime,' '));
                    $record['CREATE_TIME'] = $_lang["incomeexpend_yestoday"].$time;
                    $record['TIME_TIP']   = 'error';
                }else if(date('Y-m-d',$record['CREATE_TIME']) == date("Y-m-d",strtotime("-2 day"))){
                    $time = substr($createTime, strrpos($createTime,' '));
                    $record['CREATE_TIME'] = $_lang["incomeexpend_before_yesterday"].$time;
                    $record['TIME_TIP']   = 'error';
                }else if(date('Y-m-d',$record['CREATE_TIME']) == date("Y-m-d",strtotime("-3 day"))){
                    $time = substr($createTime, strrpos($createTime,' '));
                    $record['CREATE_TIME'] = $_lang["incomeexpend_three_days_ago"].$time;
                    $record['TIME_TIP']   = 'error';
                }else{
                    $record['CREATE_TIME'] = $createTime;
                    $record['TIME_TIP']   = 'error';
                }
                $record['EXPENSE_BUDGET']   = Tool::money2($record['EXPENSE_BUDGET']);
                $record['REVENUE_BUDGET']   = Tool::money2($record['REVENUE_BUDGET']);
				$record['EXPENSE1']			= $record['EXPENSE'];
				$record['REVENUE1']			= $record['REVENUE'];
                $record['REAL_EXPENSE']     = Tool::money2($record['REAL_EXPENSE']);
                $record['REAL_REVENUE']     = Tool::money2($record['REAL_REVENUE']);
                $record['EXPENSE']          = Tool::money2($record['EXPENSE']);
                $record['REVENUE']          = Tool::money2($record['REVENUE']);
                $recordList[] = $record;
            }
        }
        return $recordList;
    }
    /**
     * 获取某个方案的记录列表
     * @param type $planId
     * @param type $start
     * @param type $pageSize
     * @return boolean
     */
    public function oneRecordList($planId,$start = 0,$pageSize = 0){
        if(!$planId){
            return false;
        }
        $pageSize = $pageSize == 0 ? $this->pageSize : $pageSize;
        $limit = " LIMIT $start,$this->pageSize";
        $query = "SELECT r.RECORD_ID,r.PLAN_ID,r.RUN_ID,r.EXPENSE,r.REVENUE,r.CREATOR,u.USER_NAME,r.CREATE_TIME, rs.RECORD_DESC,rs.INCOME_DETAIL,rs.EXPEND_DETAIL,rs.ATTACHMENT_ID,rs.ATTACHMENT_NAME FROM payment_records AS r "
                . "LEFT JOIN user AS u ON r.CREATOR = u.USER_ID "
                . "LEFT JOIN payment_records_sub AS rs ON r.RECORD_ID = rs.RECORD_ID "
                . " WHERE r.PLAN_ID = ".SecurityFilter($planId) ." ORDER BY CREATE_TIME DESC ".$limit;
        $record = $this->_getSqlRows($query);
        return $record;
    }
    /**
     * 获取某个方案的记录个数
     * @param type $planId
     * @return int
     */
    public function getOneRecordsSize($planId){
        $query = "SELECT count(*) as count FROM payment_records WHERE PLAN_ID=".SecurityFilter($planId);
        $records = $this->_getSqlRow($query);
        if($records){
            return $records['count'];
        }else{
            return 0;
        }
    }
    /**
     * 获取简单的记录信息
     * @param type $recordId
     * @return boolean
     */
    public function getSimpleRecordInfo($recordId){
        if(!$recordId){
            return false;
        }
        $query = "SELECT r.RECORD_ID,r.PLAN_ID,r.RUN_ID,r.IS_FLOW_RECORD,r.EXPENSE,r.REVENUE,r.CREATOR,u.USER_NAME,r.YEAR,r.MONTH,r.CREATE_TIME, rs.RECORD_DESC,rs.INCOME_DETAIL,rs.EXPEND_DETAIL,rs.ATTACHMENT_ID,rs.ATTACHMENT_NAME,pp.PLAN_NAME,pp.EXPENSE_BUDGET,pp.REVENUE_BUDGET,pp.REAL_EXPENSE,pp.REAL_REVENUE FROM payment_records AS r "
                . "LEFT JOIN user AS u ON r.CREATOR = u.USER_ID "
                . "LEFT JOIN payment_records_sub AS rs ON r.RECORD_ID = rs.RECORD_ID "
                . "LEFT JOIN payment_plan AS pp ON r.PLAN_ID = pp.PLAN_ID WHERE r.RECORD_ID = ".SecurityFilter($recordId);
        $record = $this->_getSqlRow($query);
        return $record;
    }
	public function updateRecordAttachment($attachmentId,$attachmentName,$recordId)
	{
		global $connection;
		$query = "UPDATE payment_records_sub SET ATTACHMENT_ID='$attachmentId',ATTACHMENT_NAME='$attachmentName' WHERE RECORD_ID=".SecurityFilter($recordId);
		if(exequery($connection,$query)) {
			return true;
		}
		return false;
	}
	/**
	 * 编辑收支记录
	 * @global type $connection
	 * @param type $data
	 * @param type $paymentData
	 * @return boolean
	 */
	public function editPaymentRecord($data,$paymentData) {
		global $connection;
		$recordSql = 'UPDATE payment_records SET `EXPENSE` = '.SecurityFilter($data['EXPENSE']).',`REVENUE` = '.SecurityFilter($data['REVENUE']). ' WHERE RECORD_ID = '.SecurityFilter($data['RECORD_ID']);
		$subRecordSql = 'UPDATE payment_records_sub SET `RECORD_DESC` = \''.SecurityFilter($data['RECORD_DESC']).'\',`ATTACHMENT_ID` =\''.SecurityFilter($data['ATTACH_ID']).'\',`ATTACHMENT_NAME`= \''.SecurityFilter($data['ATTACH_NAME']).'\' WHERE RECORD_ID = '.SecurityFilter($data['RECORD_ID']);
		$planSql = 'UPDATE payment_plan SET `REAL_EXPENSE` = '.SecurityFilter($paymentData['REAL_EXPENSE']).',`REAL_REVENUE` = '.SecurityFilter($paymentData['REAL_REVENUE']). ' WHERE PLAN_ID='.SecurityFilter($paymentData['PLAN_ID']);
		if(exequery($connection,$recordSql)) {
			if(exequery($connection,$subRecordSql)) {
				if(exequery($connection,$planSql)) {
					return true;
				}
				return false;
			}
			return false;	
		}
		return false;
	}
	/**
	 * 删除收支记录
	 * @global type $connection
	 * @param type $recordId
	 * @param type $paymentData
	 * @return boolean
	 */
	public function deletePaymentRecord($recordId, $paymentData){
		global $connection;
		$delRecordSql = 'DELETE FROM payment_records WHERE `RECORD_ID` = ' . SecurityFilter($recordId);
		$delRecordSubSql = 'DELETE FROM payment_records_sub WHERE `RECORD_ID` = ' . SecurityFilter($recordId);
		$planSql = 'UPDATE payment_plan SET `REAL_EXPENSE` = '.SecurityFilter($paymentData['REAL_EXPENSE']).',`REAL_REVENUE` = '.SecurityFilter($paymentData['REAL_REVENUE']). ' WHERE PLAN_ID='.SecurityFilter($paymentData['PLAN_ID']);
		if(exequery($connection,$delRecordSql)) {
			exequery($connection,$delRecordSubSql);
			if(exequery($connection,$planSql)) {
				return true;
			}
			return false;
		}
		return false;
	}
    /**
     * 根据方案id获取所有记录列表
     * @param type $planId
     * @return boolean
     */
    public function getRecordsByPlanId($planId){
         if(!$planId){
            return false;
        }
        $query = "SELECT r.RECORD_ID,r.PLAN_ID,r.EXPENSE,r.REVENUE,u.USER_NAME,r.CREATE_TIME, rs.RECORD_DESC,pp.PLAN_NAME,pp.EXPENSE_BUDGET,pp.REVENUE_BUDGET,pp.REAL_EXPENSE,pp.REAL_REVENUE FROM payment_records AS r "
                . "LEFT JOIN user AS u ON r.CREATOR = u.USER_ID "
                . "LEFT JOIN payment_records_sub AS rs ON r.RECORD_ID = rs.RECORD_ID "
                . "LEFT JOIN payment_plan AS pp ON r.PLAN_ID = pp.PLAN_ID WHERE r.PLAN_ID = ".SecurityFilter($planId);
        $records = $this->_getSqlRows($query);
        return $records;
    }
    /**
     * 按全年12月统计
     * @param type $year
     * @return type
     */
    public function statAllMonth($year){
        $query = "SELECT * FROM payment_stat WHERE YEAR=".SecurityFilter($year)." ORDER BY MONTH";
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 按全年四季度统计
     * @param type $year
     * @return type
     */
    public function statAllQuarter($year){
        $query = 'SELECT SUM(`OUT`) AS `OUT`,SUM(`IN`) AS `IN`,SUM(`TIMES`) AS `TIMES`,`YEAR`,`QUARTER` 
                 FROM payment_stat WHERE `YEAR` = '.SecurityFilter($year).' GROUP BY QUARTER ORDER BY QUARTER';
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 按全年四季度统计具体几个方案
     * @param type $year
     * @param type $planId
     * @return type
     */
    public function statQuarterByPlan($year,$planId){
        $query = 'SELECT SUM(`EXPENSE`) AS `OUT`,SUM(`REVENUE`) AS `IN`,COUNT(`RECORD_ID`) AS `TIMES`,`QUARTER` FROM
            payment_records WHERE `PLAN_ID` IN('.$planId.')  AND `YEAR` = '.SecurityFilter($year).' GROUP BY `QUARTER` ORDER BY `QUARTER`';
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 按全年12月统计具体几个方案
     * @param type $year
     * @param type $planId
     * @return type
     */
    public function statMonthByPlan($year,$planId){
        $query = 'SELECT SUM(`EXPENSE`) AS `OUT`,SUM(`REVENUE`) AS `IN`,COUNT(`RECORD_ID`) AS `TIMES`,`MONTH` FROM
            payment_records WHERE `PLAN_ID` IN('.SecurityFilter($planId).')  AND `YEAR` = '.SecurityFilter($year).' GROUP BY `MONTH` ORDER BY `MONTH`';
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 统计一个月所有收支数据
     * @param type $year
     * @param type $month
     * @param type $planId
     * @return type
     */
    public function statOneMonth($year,$month,$planId){
        if($planId == ''){
            $query = 'SELECT SUM(`EXPENSE`) AS `OUT`,SUM(`REVENUE`) AS `IN`,COUNT(`RECORD_ID`) AS `TIMES`,`DAY` FROM
                payment_records WHERE `YEAR` = '.SecurityFilter($year).' AND `MONTH` = '.SecurityFilter($month).' GROUP BY `DAY` ORDER BY `DAY`';
            $stat = $this->_getSqlRows($query);
            return $stat;
        }else{
            $query = 'SELECT SUM(`EXPENSE`) AS `OUT`,SUM(`REVENUE`) AS `IN`,COUNT(`RECORD_ID`) AS `TIMES`,`DAY` FROM
                payment_records WHERE `PLAN_ID` IN('.SecurityFilter($planId).')  AND `YEAR` = '.SecurityFilter($year).' AND `MONTH` = '.SecurityFilter($month).' GROUP BY `DAY` ORDER BY `DAY`';
            $stat = $this->_getSqlRows($query);
            return $stat;
        }
    }
    /**
     * 统计一个月具体几个方案的收支数据
     * @param type $year
     * @param type $month
     * @param type $planId
     * @return boolean
     */
    public function statOneMonthByPlanId($year,$month,$planId){
        if(!$planId){
            return false;
        }
        $query = 'SELECT SUM(`EXPENSE`) AS `OUT`,SUM(`REVENUE`) AS `IN`,COUNT(`RECORD_ID`) AS `TIMES`,`DAY` FROM
                payment_records WHERE `PLAN_ID` ='.SecurityFilter($planId).'  AND `YEAR` = '.SecurityFilter($year).' AND `MONTH` = '.SecurityFilter($month).' GROUP BY `DAY` ORDER BY `DAY`';
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 统计某个方案四季度收支数据
     * @param type $year
     * @param type $planId
     * @return boolean
     */
    public function statQuarterByPlanId($year,$planId){
        if(!$planId){
            return false;
        }
        $query = 'SELECT SUM(`EXPENSE`) AS `OUT`,SUM(`REVENUE`) AS `IN`,COUNT(`RECORD_ID`) AS `TIMES`,`QUARTER` FROM
            payment_records WHERE `PLAN_ID` ='.SecurityFilter($planId).'  AND `YEAR` = '.SecurityFilter($year).' GROUP BY `QUARTER` ORDER BY `QUARTER`';
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 统计某个方案12个月收支记录
     * @param type $year
     * @param type $planId
     * @return boolean
     */
    public function statAllMonthByPlanId($year,$planId){
        if(!$planId){
            return false;
        }
        $query = 'SELECT SUM(`EXPENSE`) AS `OUT`,SUM(`REVENUE`) AS `IN`,COUNT(`RECORD_ID`) AS `TIMES`,`MONTH` FROM
            payment_records WHERE `PLAN_ID` ='.SecurityFilter($planId).'  AND `YEAR` = '.SecurityFilter($year).' GROUP BY `MONTH` ORDER BY `MONTH`';
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 统计某一个天的收支记录信息
     * @param type $year
     * @param type $month
     * @param type $day
     * @return type
     */
    public function oneDayStat($year,$month,$day){
        $query = 'SELECT SUM(pr.EXPENSE) AS EXPENSE,SUM(pr.REVENUE) AS REVENUE,COUNT(pr.RECORD_ID) AS `TIMES`,pp.PLAN_NAME FROM payment_records AS pr LEFT JOIN payment_plan AS pp '
                . ' ON pr.PLAN_ID = pp.PLAN_ID WHERE pr.YEAR ='.SecurityFilter($year).' AND pr.MONTH='.SecurityFilter($month).' AND pr.DAY='.SecurityFilter($day) .' GROUP BY pr.PLAN_ID';
        $stat = $this->_getSqlRows($query);
        return $stat;
    }
    /**
     * 根据sql语句获取多行数据
     * @global type $connection
     * @param type $query
     * @return boolean|array
     */
    private function _getSqlRows($query=''){
        global $connection;
        if($query == ''){
            return false;
        }
        $result = exequery($connection,$query);
        $data = array();
        if($result){
            while ($row = mysql_fetch_array($result,MYSQL_ASSOC)){
                array_push($data, $row);
            }
            mysql_free_result($result);
            return $data;
        }
        return false;
    }
    /**
     * 根据sql语句获取一行数据
     * @global type $connection
     * @param type $query
     * @return boolean
     */
    private function _getSqlRow($query = ''){
        global $connection;
        if($query == ''){
            return false;
        }
        $result = exequery($connection,$query);
        if($result){
            $row = mysql_fetch_array($result,MYSQL_ASSOC);
            mysql_free_result($result);
            return $row;
        }
        return false; 
    }
    /**
     * 执行sql语句
     * @param type $type
     * @param type $data
     * @param type $table
     * @param type $insertId
     * @param type $condition
     * @return boolean
     */
    private function _executeQuery($type = 'INSERT',$data = array(),$table='',$insertId = true,$condition = array()){
        if($table == ''){
            return false;
        }
        switch (strtoupper($type)){
            case 'INSERT':
                if(empty($data)){
                    return false;
                }
                return $this->_executeInsert($data,$table,$insertId);
                break;
            case 'UPDATE':
                if(empty($data) || empty($condition)){
                    return false;
                }
                return $this->_executeUpdate($data,$table,$condition);
                break;
            default:
        }
    }
    /**
     * 执行插入操作
     * @global type $connection
     * @param type $data
     * @param type $table
     * @param type $insertId
     * @return boolean
     */
    private function _executeInsert($data,$table,$insertId){
        global $connection;
        $query      = "INSERT INTO `$table`(";
        $nameQuery  = '';
        $valueQuery = '';
        foreach($data as $k => $v){
            $k      = strtoupper($k);
            $nameQuery .= "`$k`,";
            if(is_numeric($v)){
                $valueQuery .= "$v,";
            }else{
                $valueQuery .= "'$v',";
            }
        }
        $nameQuery  = substr($nameQuery,0,strrpos($nameQuery, ','));
        $valueQuery = substr($valueQuery,0,strrpos($valueQuery, ','));
        $query      .= $nameQuery.') VALUES('.$valueQuery.')';
        if(exequery($connection,$query)){
            if($insertId){
                return mysql_insert_id();
            }else{
                return true;
            }
        }
        return false;
    }
    /**
     * 执行更新操作
     * @global type $connection
     * @param type $data
     * @param type $table
     * @param type $condition
     * @return type
     */
    private function _executeUpdate($data,$table,$condition){
        global $connection;
        $query = "UPDATE `$table` SET ";
        foreach($data as $k => $v){
            $k = strtoupper($k);
            if(is_numeric($v)){
                $query .= "`$k`=$v,";
            }else{
                $query .= "`$k`='$v',";
            }
        }
        $query  = substr($query,0,strrpos($query, ','));
        $query .= ' WHERE 1=1 ';
        foreach($condition as $k => $v){
            $k = strtoupper($k);
            if(is_numeric($v)){
                $query .= " AND `$k` = $v";
            }else{
                $query .= " AND `$k` = '$v'";
            }
        }
        return exequery($connection,$query);
    }
    /**
     * 根据具体条件搜索方案列表
     * @param type $selectName
     * @param type $condition
     * @param type $order
     * @param type $group
     * @param type $limit
     * @param type $link
     * @return boolean
     */
    private function _planListSelect($selectName,$condition,$order,$group,$limit,$link = 'AND'){
        $queryList = 'SELECT ';
        if(empty($selectName)){
            $queryList .= '*';
        }else{
            foreach ($selectName as $k => $v){
                $queryList .= "$v,";
            }
            $queryList  = substr($queryList,0,strrpos($queryList, ','));
        }
        $queryList .= ' FROM payment_plan as p LEFT JOIN payment_plan_type as pt ON p.PLAN_TYPE = pt.TYPE_ID WHERE 1=1 ';
        
        $queryID = 'SELECT p.PLAN_ID FROM payment_plan as p WHERE 1=1 ';
        $query   = '';
        if($this->userSelect == true){
           $query .= " AND (p.CREATOR= '$this->userId' OR p.ALL_USER = 2 OR (FIND_IN_SET('".SecurityFilter($this->userId)."',p.USER_ID) OR FIND_IN_SET('".SecurityFilter($this->privId)."',p.ROAL_ID) OR FIND_IN_SET('".SecurityFilter($this->deptId)."',p.DEPT_ID))) ";
        }
        if(!empty($condition['like'])){ 
            $query .= ' AND (';
            foreach ($condition['like'] as $k => $v){
                $query .= $k .' LIKE '. "'%".SecurityFilter($v) ."%' $link ";
            }
            $query  = substr($query,0,strrpos($query,$link));
            $query  .= ')';
        }
        if(!empty($condition['eq'])){
            $query .= ' AND (';
            foreach ($condition['eq'] as $k => $v){
                if(is_numeric($v)){
                    $query .= $k .' = '. SecurityFilter($v)." $link ";
                }else{
                    $query .= $k .' = '. "'".SecurityFilter($v)."' $link ";
                }
            }
            $query  = substr($query,0,strrpos($query,$link));
            $query  .= ')';
        }
        if(!empty($condition['neq'])){
            $query .= ' AND (';
            foreach ($condition['neq'] as $k => $v){
                if(is_numeric($v)){
                    $query .= $k .' != '. SecurityFilter($v)." $link ";
                }else{
                    $query .= $k .' != '. "'".SecurityFilter($v)."' $link ";
                }
            }
            $query  = substr($query,0,strrpos($query,$link));
            $query  .= ')';
        }
        if(!empty($condition['gt'])){
            $query .= ' AND (';
            foreach ($condition['gt'] as $k => $v){
                if(is_numeric($v)){
                    $query .= $k .' >= '. SecurityFilter($v)." $link ";
                }else{
                    $query .= $k .' >= '. "'".SecurityFilter($v)."' $link ";
                }
            }
            $query  = substr($query,0,strrpos($query,$link));
            $query  .= ')';
        }
        $countQuery = $query;
        if($group){
            $query .= $group;
        }
        if($order){
            if(empty($condition['like'])){
                $query .= $order;
            }
        }
        if($limit){
            $query .= $limit;
        }
        $planIds  = $this->_getSqlRows($queryID.$query);
        if($planIds){
            $inQuery = 'AND p.PLAN_ID IN (';
            foreach($planIds as $key => $value){
                $inQuery .= SecurityFilter($value['PLAN_ID']).",";
            }
            $inQuery  = substr($inQuery,0,strrpos($inQuery,','));
            $inQuery  .= ')';
            $queryList .= $inQuery;            
            $lists  = $this->_getSqlRows($queryList.$order);
            if($condition['count'] == 1){
                $countSql = "SELECT count(*) as count FROM payment_plan as p WHERE 1=1 ".$countQuery;
                $planRow = $this->_getSqlRow($countSql);
                $planCount = $planRow['count'];
                return array('totalCount' => $planCount,'list' => $lists);
            }else{
                return $lists;
            }
        }
        if($condition['count'] == 1){
            $countSql = "SELECT count(*) as count FROM payment_plan as p WHERE 1=1 ".$countQuery;
            $planRow = $this->_getSqlRow($countSql);
            $planCount = $planRow['count'];
            return array('totalCount' => $planCount,'list' => '');
        }else{
            return '';
        }
    }
}
