(function($) {

    var methods = {
        init: function(options) {
            var settings = $.extend({

                //报表ID
                reportID: false,

                //数据源ID
                dataSourceID: false,

                //报表创建完成回掉函数
                onCreate: $.noop,

                //动态数据 更新Interval
                updateInterval: false

            }, options);

            return this.each(function() {

                var $this = $(this);

                $this.data({
                    lazyReportSettings: settings
                });

                if (!settings.reportID && !settings.dataSourceID) {
                    alert('缺少参数');
                }

                var monthHtml = [];
                for (var i = 1; i <= 12; i++) {
                    if(i==settings.time_month){
                        monthHtml.push('<option selected="selected" value="' + i + '">' + i + '</option>');
                    }else{
                        monthHtml.push('<option value="' + i + '">' + i + '</option>');
                    }
                }

                var yearHtml = [];
				var nowDate = new Date();
				var nowYear = nowDate.getFullYear();
                for (var i = nowYear; i > nowYear - 5; i--) {
                    if(i==settings.time_year){
                         yearHtml.push('<option selected="selected" value="' + i + '">' + i + '</option>');
                    }else{
                         yearHtml.push('<option value="' + i + '">' + i + '</option>');
                    }

                }

                $this.addClass("lazy-report").html('<div class="report-filter-wrap" style="display:inline-block;">\
                                <ul class="report-type-filter" style="float:left;">\
                                    <li mode="year" class="current">年</li>\
                                    <li mode="quarter">季</li>\
                                    <li mode="month">月</li>\
                                    <li mode="day">日</li>\
                                </ul>\
                                <select class="year-select">' + yearHtml.join('') + '</select>\
                                <select class="month-select">' + monthHtml.join('') + '</select>\
                            </div>\
                            <div class="chart-preivew" style="text-align:center;"></div>');

                if(settings.time_filter){
                    $this.find(".report-filter-wrap li.current").removeClass("current hover");
                    $this.find(".report-filter-wrap li[mode="+settings.time_filter+"]").addClass("current");
                }

                //年、月切换重新渲染报表
                $this.find(".year-select,.month-select").change(function() {
                    methods.createChart.call($this);
					if(0 < $this.find(".report-filter-wrap li[class='current']").index()){
						$this.find('.report-filter-wrap').css('display', 'block');
					}
                });

                //日期显示模式切换，重新渲染报表
                $this.find(".report-filter-wrap li").hover(function() {
                    if (!$(this).hasClass("current")) {
                        $(this).addClass("hover");
                    }

                }, function() {
                    if (!$(this).hasClass("current")) {
                        $(this).removeClass("hover");
                    }

                }).click(function() {
                    $this.find(".report-filter-wrap li").removeClass("current hover");
                    $(this).addClass("current");

                    $this.find(".year-select,.month-select").selectpicker("hide");
					methods.createChart.call($this);

					if(0 == $(this).index()){
						$(this).parents('.report-filter-wrap').css('display', 'inline-block');
					}else{
						$(this).parents('.report-filter-wrap').css('display', 'block');
					}

                    return false;
                });
                $this.find("select").selectpicker({
                    width: "100px"
                });

            });
        },
        _getDateValue: function(mode) {
            var dateValue, $this = $(this);
            switch (mode) {
                case 'year':
                    dateValue = $this.find(".year-select option:last").val() + "-" + $this.find(".year-select option:first").val();
                    break;
                case 'quarter':
                case 'month':
                    $this.find(".year-select").selectpicker("show");
                    dateValue = $this.find(".year-select").val();
                    break;
                case 'day':
                    $this.find(".year-select,.month-select").selectpicker("show");
                    dateValue = $this.find(".year-select").val() + "-" + $this.find(".month-select").val();
                    break;
            }

            return dateValue;
        },

        /**
         * 重绘报表
         * @return {[type]} [description]
         */
        reflowChart: function() {
            if ($(this).find('.chart-preivew').highcharts()) {
                $(this).find('.chart-preivew').highcharts().reflow();
            }
        },
        createChart: function(chartData) {

            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyReportSettings");

                if (settings.updateInterval) {
                    clearInterval(settings.updateInterval);
                }

                $this.find(".report-filter-wrap").hide();
                $this.find(".year-select,.month-select").selectpicker("hide");

                if (chartData) {
                    $this.data("chartData", chartData);
                } else {
                    chartData = $this.data("chartData");
                }

                //console.log(chartData);

                var dateType = $this.find(".report-filter-wrap li").filter(function() {
                    return $(this).hasClass('current');
                }).attr("mode");

                // console.log(dateType);

                var dateValue = methods._getDateValue.call($this, dateType);

                $.ajax({
                    url: "/general/report/inc/lazy_report.php",
                    data: $.extend(settings, {
                        reportID: settings.reportID,
                        op: "getReportData",
                        dateType: dateType,
                        dateValue: dateValue,
                        searchInfor: chartData && chartData.searchInfor ? chartData.searchInfor : "",
                        dataSourceID: settings.dataSourceID
                    })

                }).done(function(result) {
                    if($(".excel-wrap").is(":visible")){
                        $(".excel-wrap").hide();
                    }
                    if (result) {

                        var parsedData = $.parseJSON(result);

						var chartType;
                        var excel_name ;
						if(isset(parsedData.chartInfor) && isset(parsedData.chartInfor.CHART_TYPE)){
							chartType = parsedData.chartInfor.CHART_TYPE;
						}else if(isset(parsedData.chartType)){
							chartType = parsedData.chartType;
						}else if(isset(chartData.chartType)){
							chartType = chartData.chartType;
						}



                        var chartTitle = parsedData.chartInfor && parsedData.chartInfor.CHART_TITLE ? parsedData.chartInfor.CHART_TITLE : parsedData.chartTitle;
                        excel_name = chartTitle || "";
                        var isStack = chartType.indexOf("_stack") != -1;
                        var isPolar = chartType.indexOf("_polar") != -1;


                        if (parsedData.dataSourceInfor.DATASOURCE_GROUPBY_TYPE == "date") {
                            $this.find(".report-filter-wrap").show();
                        }

                        var chartSettings = {
                            chart: {
                                type: chartType.replace(/_stack|_polar/, "")
                            },
                            title: {
                                text: chartTitle
                            },
                            xAxis: {
                                type: "category",
                                labels: {
                                    rotation: 45
                                }
                            },
                            yAxis: {
                                title: {
                                    text: parsedData.yAxisTitle ? parsedData.yAxisTitle : parsedData.dataSourceInfor.DATASOURCE_DATA_ANALYSIS_TITLE
                                },

                                stackLabels: {
                                    enabled: true
                                }
                            },
                            credits: {
                                enabled: false
                            },
                            tooltip: {
                                pointFormat: '{point.y}',
                            },
                            series: parsedData.series
                        };

                        var advancedSetting = {};

                        //堆栈图
                        if (isStack) {
                            advancedSetting = {
                                plotOptions: {
                                    series: {
                                        stacking: 'normal'
                                    }
                                }
                            };
                        }

                        //散点图
                        if (chartType == "scatter") {
                            advancedSetting = {
                                plotOptions: {
                                    scatter: {
                                        tooltip: {
                                            headerFormat: "",
                                            pointFormat: '{point.name}<br>{point.y}'
                                        }
                                    }
                                }
                            }
                        }

                        //气泡图
                        if (chartType == "bubble") {
                            advancedSetting = {
                                plotOptions: {
                                    bubble: {
                                        tooltip: {
                                            headerFormat: "",
                                            pointFormat: '{point.name}<br>{point.y}'
                                        }
                                    }
                                }
                            }
                        }

                        //excel表
                        if (chartType == "excel") {
                            var content = parsedData['series'];
                            var table_body = '';
                            var i = 1;
                            var excel_length = content.length;
                            var title = parsedData.dataSourceInfor['DATASOURCE_DATA_ANALYSIS_TITLE'];
                            if(excel_length == 1){
                                table_body += "<tr>";
                                var header_data = content[0];
                                table_body += '<td style="border:1px solid #CCC;text-align:center;">'+header_data['name']+'</td>';
                                for(z in header_data['data']){
                                    table_body += '<td style="border:1px solid #CCC;text-align:center;">'+header_data['data'][z]['name']+'</td>';
                                    i++;
                                }
                                table_body += "</tr>";
                                table_body += "<tr>";
                                table_body += '<td style="border:1px solid #CCC;text-align:center;">'+title+'</td>';
                                for(z in header_data['data']){
                                    table_body += '<td style="border:1px solid #CCC;text-align:center;">'+header_data['data'][z]['y']+'</td>';
                                }
                                table_body += "</tr>";
                            }else{
                                 table_body += "<tr>";
                                    var header_data = content[0];
                                    table_body += '<td style="border:1px solid #CCC;text-align:center;">'+title+'</td>';
                                    for(z in header_data['data']){
                                        table_body += '<td style="border:1px solid #CCC;text-align:center;">'+header_data['data'][z]['name']+'</td>';
                                        i++;
                                    }
                                table_body += "</tr>";

                                for(x in content){
                                    table_body += "<tr>";
                                        var content_data = content[x];
                                        table_body += '<td style="border:1px solid #CCC;text-align:center;">'+content_data['name']+'</td>';
                                        for(z in content_data['data']){
                                            table_body += '<td style="border:1px solid #CCC;text-align:center;">'+content_data['data'][z]['y']+'</td>';
                                        }
                                    table_body += "</tr>";
                                }
                            }

                            var table = '<p style="font-size:16px;text-align:center;margin-bottom:20px" >'+excel_name+'</p>'
                            table += '<table style="margin:10px auto;width:98%;">';
                            table += table_body;
                            table += '</table>';
                        }

                        //动态图
                        if (chartType == "spline") {
                            advancedSetting = {
                                chart: {
                                    events: {
                                        load: function() {

                                            if (parsedData.dataSourceInfor.DATASOURCE_TYPE == "custom") {

                                                var dataSourceParam = parsedData.dataSourceInfor.DATASOURCE_PARAM;
                                                var parsedParam = $.parseJSON(dataSourceParam);

                                                var series = this.series[0];
                                                settings.updateInterval = setInterval(function() {
                                                    $.ajax({
                                                        url: "/general/report/inc/lazy_report.php",
                                                        data: {
                                                            op: "getUpdateData",
                                                            url: parsedParam.url
                                                        }
                                                    }).done(function(result) {
                                                        if (result) {
                                                            var updateData = $.parseJSON(result);
                                                            series.addPoint({
                                                                name: updateData.name,
                                                                y: updateData.y
                                                            }, true, true);
                                                        }
                                                    });
                                                }, 3000);
                                            }
                                        }
                                    }
                                }
                            }
                        }

                        //极地图
                        if (isPolar) {
                            advancedSetting = {
                                chart: {
                                    type: "line",
                                    polar: true
                                }
                            }
                        }
                        $.extend(chartSettings, advancedSetting);
                        settings.onCreate.call(this, parsedData.dataSourceInfor);
                         if (chartType != "excel"){
                                    $this.find('.chart-preivew').highcharts(chartSettings);
                                }else{
                                    $this.find('.chart-preivew').html(table);
                                }
                    }
                });

            });
        },
        settings: function(name) {
            var $this = $(this),
                settings = $this.data("lazyReportSettings");
            return settings[name];
        }
    };

    $.fn.LazyReport = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazyReport');
        }

    };
})(jQuery);
