<?
include_once 'general/webmail/inc/class.api.php';
/*
 * 接收邮件
 */
class Receive extends UebiMiau_core {
	private $connection;

	//是否使用SSL连接服务器
	private $isSslAuth;

	//服务器
	private $host;

	//端口
	private $port;

	//用户名
	private $userName;

	//密码
	private $password;

	//文件夹
	private $userFolder;

	//当前邮箱
	private $userMail;

	//协议
	private $protocol;

	//标识符
	private $identifier;

	//错误信息
	private $errorMessage;

	//收取邮件数量
	private $limit;

	/*
	 * 构造函数
	 */
	function __construct($host, $port, $userName, $password, $userMail, $config, $isSslAuth = false, $limit = -1, $protocol) {

		//基于以微秒计的当前时间，生成一个唯一的 标识符。
		$this -> identifier = uniqid("");

		$this -> host = $host;
		$this -> port = $port;
		$this -> userName = $userName;
		$this -> password = decrypt($password);
		$this -> isSslAuth = $isSslAuth;
		$this -> userMail = $userMail;
		$this -> limit = $limit;
		$this -> protocol = $protocol;
		$this -> userFolder = $config["userFolder"];
		$this -> use_html = $config["useHtml"];
		$this -> allow_scripts = $config["allowScripts"];
	}

	/*
	 * 是否已连接服务器
	 */
	function isConnected() {
		if (!$this -> connection) {
			return false;
		}

		//从封装协议文件指针中取得报头
		$connectionStatus = @stream_get_meta_data($this -> connection);

		//如果流到达文件末尾
		if ($connectionStatus["eof"]) {
			@fclose($this -> connection);
			return false;
		}
		return true;
	}

	/*
	 * 获取错误信息
	 */
	function GetErrorMessage() {
		return $this -> errorMessage;
	}

	/*
	 * 设置错误信息
	 */
	function SetErrorMessage($errorMessage) {
		$this -> errorMessage = $errorMessage;
	}

	/*
	 * 连接服务器
	 */
	function Connect() {
		global $_lang;

		//如果已经连接，则不再连接
		if ($this -> isConnected()) {
			return true;
		}

		//是否使用SSL连接服务器
		if ($this -> isSslAuth) {
			$this -> host = 'ssl://' . $this -> host;
		}

		$this -> connection = @fsockopen($this -> host, $this -> port, $errorNumber, $errorMessage);

		stream_set_timeout($this -> connection, 5);

		if (!$this -> connection) {
			$this -> SetErrorMessage($_lang['email_connect_to_server_fail']);
			return false;
		}

		if (!$this -> GetCommandResponse(true)) {
			return false;
		}

		//验证用户名、密码
		if ($this -> protocol != "imap") {

			$this -> SendCommand("USER " . $this -> userName);
			if (!$this -> GetCommandResponse(true)) {
				$this -> SetErrorMessage($_lang['email_address_or_password_error']);
				return false;
			}

			$this -> SendCommand("PASS " . $this -> password);
			if (!$this -> GetCommandResponse(true)) {
				$this -> SetErrorMessage($_lang['email_address_or_password_or_server_error']);
				return false;
			}
		}
		return true;
	}

	/*
	 * 关闭连接
	 */
	function Disconnect() {
		global $_lang;
		$flag = true;
		if ($this -> isConnected()) {
			if (!$this -> SendCommand("QUIT")) {
				$flag = false;
			}
			if (!$this -> GetCommandResponse(true)) {
				$flag = false;
			}
			if (!fclose($this -> connection)) {
				$this -> SetErrorMessage($_lang['email_close_connection_fail']);
				$flag = false;
			}
			$this -> connection = "";
		}
		return $flag;
	}

	/*
	 * 发送命令
	 */
	function SendCommand($command) {
		global $_lang;
		try {
			if ($this -> protocol == "imap") {
				$command = $this -> identifier . " " . $command;
			}
			if (fwrite($this -> connection, "$command\r\n") === false) {
				$this -> SetErrorMessage($_lang['email_send_command_fail']);
				return false;
			}
			return true;
		} catch(Exception $e) {
			return false;
		}
	}

	/*
	 * 获取发送命令的返回值
	 */
	function GetCommandResponse($checkResponse = false) {
		global $_lang;

		$string = fgets($this -> connection);
		if (!$string) {
			$this -> SetErrorMessage($_lang['email_execute_command_fail']);
			return false;
		}

		$buffer = rtrim($string);

		//是否检查返回结果
		if ($checkResponse) {
			if ($this -> protocol == "imap") {
				$regexp = "^([ ]?\\*[ ]?OK)";
			} else {
				$regexp = "^(\\+OK)";
			}
			if (ereg($regexp, $buffer)) {
				return true;
			} else {
				$this -> SetErrorMessage($_lang['email_execute_command_fail']);
				return false;
			}
		} else {
			return $buffer;
		}
	}

	/*
	 *获取服务器上新邮件的uidl数组
	 * @return array 服务器上新邮件uidl数组
	 */
	function GetNewEmailUidl() {
		//获取服务器uidl
		if (!$this -> SendCommand("UIDL")) {
			return false;
		}

		if (!$this -> GetCommandResponse(true)) {
			return false;
		}

		//获取服务器的uidl数组
		while (!feof($this -> connection)) {
			$buffer = $this -> GetCommandResponse();
			if (trim($buffer) == '.') {
				break;
			}
			$uidlSplit = split(" ", $buffer);
			if (count($uidlSplit) == 2) {
				$serverUidlArray[trim($uidlSplit[0])] = trim($uidlSplit[1]);
			}
		}

		//反转数组，便于指定了限定数量时，从最新的邮件开始获取
		if (is_array($serverUidlArray)) {
			$serverUidlArray = array_reverse($serverUidlArray, true);
		} else {
			return false;
		}

		//获取缓存中的uidl
		$cacheUidlArray = $this -> GetUidlCache();

		//比对服务器上的uidl和本地缓存，不存在于本地缓存的是需要获取的新邮件
		foreach ($serverUidlArray as $key => $value) {

			//若没有本地uidl缓存，则直接写入新邮件uidl数组中
			if (!$cacheUidlArray) {
				$newUidlArray[$key] = $value;
			} else {

				//不存在本地uidl缓存中的邮件，写入新邮件uidl数组中
				if (array_search($value, $cacheUidlArray) === false) {
					$newUidlArray[$key] = $value;
				}
			}

			//如果指定了收取数量，则只收取指定数量的邮件
			if ($this -> limit != -1 && count($newUidlArray) == $this -> limit) {
				break;
			}
		}
		return $newUidlArray;
	}

	/*
	 * 获取新邮件的数量、大小
	 */
	function GetNewEmailCount() {
		try {

			if (!$this -> isConnected()) {
				if (!$this -> Connect()) {
					return false;
				}
			}

			//获取服务器上新邮件的uidl数组
			$newEmailUidlArray = $this -> GetNewEmailUidl();

			//获取服务器上所有新邮件的序号、大小
			if (!$this -> SendCommand("LIST")) {
				return false;
			}

			if (!$this -> GetCommandResponse()) {
				return false;
			}

			$totalSize = 0;
			$totalCount = 0;
			if (is_array($newEmailUidlArray)) {

				//获取需要获取的邮件起始序号和结束序号
				$keyArray = array_keys($newEmailUidlArray);

				//因为数组被反转过了，所以序号小的在后面
				$startNumber = $keyArray[count($newEmailUidlArray) - 1];
				$endNumber = $keyArray[0];
				while (!feof($this -> connection)) {
					$buffer = $this -> GetCommandResponse();
					if (trim($buffer) == '.')
						break;
					$bufferSplit = split(" ", $buffer);
					if (count($bufferSplit) == 2) {
						$number = $bufferSplit[0];
						$size = $bufferSplit[1];
						if ($number >= $startNumber && $number <= $endNumber) {
							$totalSize += $size;
						}
					}
				}

				$totalCount = count($newEmailUidlArray);
			}

			//MB
			if ($totalSize > 1024 * 1024) {
				$totalSize = ceil($totalSize / 1024 / 1024);
				$unit = ' MB';
			}
			//KB
			elseif ($totalSize > 1024) {
				$totalSize = ceil($totalSize / 1024);
				$unit = ' KB';
			}
			//B
			else {
				$unit = ' B';
			}

			//断开连接
			$this -> Disconnect();
			$newEmailInfor["newEmailCount"] = $totalCount;
			$newEmailInfor["newEmailTotalSize"] = $totalSize . $unit;
			return $newEmailInfor;
		} catch(Exception $e) {
			return false;
		}
	}

	function ReceiveNewEmail() {

		//连接服务器
		if (!$this -> isConnected()) {
			if (!$this -> Connect()) {
				return false;
			}
		}

		//获取服务器上新邮件的uidl数组
		$newEmailUidlArray = $this -> GetNewEmailUidl();

		//所有邮件信息数组
		$mailInforArray = array();

		//需要保存到缓存的uidl(获取成功的邮件uidl)
		$needSaveUidlArray = array();

		if (is_array($newEmailUidlArray)) {
			$email_count = count($newEmailUidlArray);
			foreach ($newEmailUidlArray as $key => $value) {
				if ($email_count > 1) {
					$this -> Connect();
				}
				if (!$this -> SendCommand("RETR " . $key)) {
					continue;
				}
				if (!$this -> GetCommandResponse(true)) {
					continue;
				}

				$mailSource = '';
				while (!feof($this -> connection)) {
					$buffer = $this -> GetCommandResponse();
					if (trim($buffer) == ".") {
						break;
					}
					$mailSource .= $buffer . "\r\n";
				}

				//保存当前邮件uidl
				array_push($needSaveUidlArray, $value);

				//解析整个邮件
				$mainInfor = $this -> Decode($mailSource);

				//移除header源文件内容，只需要解析好的header
				array_shift($mainInfor);

				//保存邮件源文件
				$emailSourceFileName = $this -> SaveMailSource($mailSource);

				$mainInfor["sourceFileName"] = $emailSourceFileName;
				array_push($mailInforArray, $mainInfor);
				if ($email_count > 1) {
					$this->Disconnect();
				}
			}
		}

		//获取成功的邮件的uidl保存到缓存中
		$this -> SaveUidlCache($needSaveUidlArray);
		return $mailInforArray;
	}

	/*
	 *保存邮件源文件
	 * @param string $mailSource 邮件源文件
	 * @return string 文件名称(需保存进数据库)
	 */
	function SaveMailSource($mailSource) {
		$fileName = md5(uniqid());
		$filePath = $this -> userFolder . '/' . $this -> userMail . "/inbox/";

		if (!file_exists($filePath)) {
			mkdir($filePath, 0777, true);
		}

		if (!file_put_contents($filePath . $fileName . ".eml", $mailSource)) {
			return false;
		} else {
			return $fileName;
		}
	}

	/*
	 * 保存uidl缓存
	 * @param array $uidlArray 服务器上的新邮件uidl数组
	 * @param bool true-成功/false-失败
	 */
	function SaveUidlCache($uidlArray) {
		$userPath = $this -> userFolder . '/' . $this -> userMail. '/' . $_SESSION["LOGIN_USER_ID"] . "/";
		$mailFile = $this -> userFolder . '/' . $this -> userMail . "/inbox/uidl.cache";

		if (!is_dir($userPath)) {
			mkdir($userPath, 0777, true);

			if (file_exists($mailFile)) {
				if ($this->makeFile($_SESSION["LOGIN_USER_ID"])) {
					copy($mailFile, $userPath.'/uidl.cache');
				}
			}
		}

		//获取缓存uidl数组
		$cacheUidlArray = $this -> GetUidlCache();
		if (!$cacheUidlArray) {
			$newUidlArray = $uidlArray;
		} else {
			//合并服务器上的新uidl数组和本地缓存uidl数组
			$newUidlArray = array_merge($cacheUidlArray, $uidlArray);
		}

		//写入uidl缓存文件
		if (!file_put_contents($userPath . "uidl.cache", json_encode($newUidlArray))) {
			return false;
		}

		return true;
	}

	/*
	 * 获取uidl缓存
	 * @return array 本地缓存uidl数组
	 */
	function GetUidlCache() {
		$userPath = $this -> userFolder . '/' . $this -> userMail. '/' . $_SESSION["LOGIN_USER_ID"] . "/";
		$mailFile = $this -> userFolder . '/' . $this -> userMail . "/inbox/uidl.cache";

		if (!is_dir($userPath)) {
			mkdir($userPath, 0777, true);

			if (file_exists($mailFile) ) {
				if ($this->makeFile($_SESSION["LOGIN_USER_ID"])) {
					copy($mailFile, $userPath.'/uidl.cache');
				}
			}
		}

		$filename = $userPath.'/uidl.cache';
		if (!file_exists($filename)) {
			return false;
		}

		return json_decode(file_get_contents($filename));
	}

	function makeFile($userId) {
		$id = getEmailboxId($this->userMail, $userId);

		if (!$id) {
			return false;
		}

		return haveEmailboxMails($id, $userId);
	}
}
?>