<!--
/**
 * 返回日期
 * @param d the delimiter
 * @param p the pattern of your date
 */
String.prototype.toDate = function(x, p) {
  if(x == null) x = "-";
  if(p == null) p = "ymd";
  var a = this.split(x);
  var y = parseInt(a[p.indexOf("y")]);
  //remember to change this next century ;)
  if(y.toString().length <= 2) y += 2000;
  if(isNaN(y)) y = new Date().getFullYear();
  var m = parseInt(a[p.indexOf("m")]) - 1;
  var d = parseInt(a[p.indexOf("d")]);
  if(isNaN(d)) d = 1;
  return new Date(y, m, d);
}

/**
 * 格式化日期

 * @param   d the delimiter
 * @param   p the pattern of your date
 * @author  meizz
 */
Date.prototype.format = function(style) {
  var o = {
    "M+" : this.getMonth() + 1, //month
    "d+" : this.getDate(),      //day
    "h+" : this.getHours(),     //hour
    "m+" : this.getMinutes(),   //minute
    "s+" : this.getSeconds(),   //second
    "w+" : "天一二三四五六".charAt(this.getDay()),   //week
    "q+" : Math.floor((this.getMonth() + 3) / 3),  //quarter
    "S"  : this.getMilliseconds() //millisecond
  }
  if(/(y+)/.test(style)) {
    style = style.replace(RegExp.$1,
    (this.getFullYear() + "").substr(4 - RegExp.$1.length));
  }
  for(var k in o){
    if(new RegExp("("+ k +")").test(style)){
      style = style.replace(RegExp.$1,
        RegExp.$1.length == 1 ? o[k] :
        ("00" + o[k]).substr(("" + o[k]).length));
    }
  }
  return style;
};

/**
 * 日历类

 * @param   beginYear 1990
 * @param   endYear   2010
 * @param   lang      0(中文)|1(英语) 可自由扩充

 * @param   dateFormatStyle  "yyyy-MM-dd";
 */
function Calendar(beginYear, endYear, lang, dateFormatStyle) {
  this.beginYear = 1990;
  this.endYear = 2030;
  this.lang = 0;            //0(中文) | 1(英文)
  this.dateFormatStyle = "yyyy-MM-dd";

  if (beginYear != null && endYear != null){
    this.beginYear = beginYear;
    this.endYear = endYear;
  }
  if (lang != null){
    this.lang = lang
  }

  if (dateFormatStyle != null){
    this.dateFormatStyle = dateFormatStyle
  }

  this.dateControl = null;
  this.panel = this.getElementById("calendarPanel");
  this.form  = null;

  this.date = new Date();
  this.year = this.date.getFullYear();
  this.month = this.date.getMonth();


  this.colors = {
  "cur_word"      : "#FFFFFF",  //当日日期文字颜色
  "cur_bg"        : "#EEEEEE",  //当日日期单元格背影色
  "sun_word"      : "#999999",  //星期天文字颜色

  "sat_word"      : "#999999",  //星期六文字颜色

  "td_word_light" : "#333333",  //单元格文字颜色

  "td_word_dark"  : "#CCCCCC",  //单元格文字暗色

  "td_bg_out"     : "#FFFFFF",  //单元格背影色
  "td_bg_over"    : "#FFCC00",  //单元格背影色
  "tr_word"       : "#333333",  //日历头文字颜色

  "tr_bg"         : "#FFFFFF",  //日历头背影色

  "input_border"  : "",  //input控件的边框颜色

  "input_bg"      : "#77B5F9",   //input控件的背影色
  "divide_line"   : "#333333", 
  "header_tr"     : "#77B5F9",
  "select_date"   : "#77B5F9"
  }

  this.draw();
  this.bindYear();
  this.bindYearIpt();
  this.bindMonth();
  this.bindMonthIpt();
  this.changeSelect();
  this.bindData();
}

/**
 * 日历类属性（语言包，可自由扩展）
 */
Calendar.language = {
  "year"   : [[""], [""]],
  "yeaript"   : [["年"], [""]],
  "months" : [["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],
        ["JAN","FEB","MAR","APR","MAY","JUN","JUL","AUG","SEP","OCT","NOV","DEC"]
         ],
  "weeks"  : [["日","一","二","三","四","五","六"],
        ["Sun","Mon","Tur","Wed","Thu","Fri","Sat"]
         ],
  "clear"  : [["清空"], ["CLS"]],
  "today"  : [["今天"], ["TODAY"]],
  "close"  : [["关闭"], ["CLOSE"]]
}

Calendar.prototype.draw = function() {
  calendar = this;

  var mvAry = [];
  mvAry[mvAry.length]  = '  <form name="calendarForm" style="margin: 0px;">';
  mvAry[mvAry.length]  = '    <table width="100%" border="0" cellpadding="0" cellspacing="0">';
  mvAry[mvAry.length]  = '      <tr bgcolor="' + calendar.colors["header_tr"] + '">';
  mvAry[mvAry.length]  = '        <th align="left" width="1%"><input style="border: 0px solid ' + calendar.colors["input_border"] + ';background-color:' + calendar.colors["input_bg"] + ';width:16px;height:20px;font-weight:bolder;color:#FFFFFF;" name="prevMonth" type="button" id="prevMonth" value="&lt;" /></th>';
  mvAry[mvAry.length]  = '        <th align="center" width="98%" nowrap="nowrap"><select name="calendarYear" id="calendarYear" style="font-size:12px;display:none;"></select><input type="button" id="calendarYearIpt" value="" style="border:0px solid '+calendar.colors["header_tr"]+';background-color:'+calendar.colors["header_tr"]+';width:50px;font-weight:bold;color:#FFFFFF "><select name="calendarMonth" id="calendarMonth" style="font-size:12px;display:none"></select><input type="button" id="calendarMonthIpt" value="" style="border:0px solid '+calendar.colors["header_tr"]+';background-color:'+calendar.colors["header_tr"]+';width:50px;font-weight:bold;color:#FFFFFF "></th>';
  mvAry[mvAry.length]  = '        <th align="right" width="1%"><input style="border: 0px solid ' + calendar.colors["input_border"] + ';background-color:' + calendar.colors["input_bg"] + ';width:16px;height:20px;font-weight:bolder;color:#FFFFFF;" name="nextMonth" type="button" id="nextMonth" value="&gt;" /></th>';
  mvAry[mvAry.length]  = '      </tr>';
  mvAry[mvAry.length]  = '    </table>';
  mvAry[mvAry.length]  = '    <table id="calendarTable" width="100%" style="border:0px solid #CCCCCC; border="0" cellpadding="1" cellspacing="0" align="center">';
  mvAry[mvAry.length]  = '	<tr><th colspan="7"  height="10"></th></tr>';
  mvAry[mvAry.length]  = '      <tr>';
  for(var i = 0; i < 7; i++) {
    mvAry[mvAry.length]  = '      <th style="font-weight:normal;background-color:' + calendar.colors["tr_bg"] + ';color:' + calendar.colors["tr_word"] + ';font-size:12px">' + Calendar.language["weeks"][this.lang][i] + '</th>';
  }
  mvAry[mvAry.length]  = '      </tr>';
  mvAry[mvAry.length]  = '	<tr><th colspan="7" bgcolor="' + calendar.colors["divide_line"] + '" height="1"></th></tr>';
  
  /*
  var mainWin = parent.calendarmainFrame;//获取calendar页面的viewType selectDate selectUser
  var viewType = mainWin.tmpCalForm.viewType.value
  if (viewType == 2){
  }
  */
  for(var i = 0; i < 6;i++){
    mvAry[mvAry.length]  = '    <tr align="center">';
    for(var j = 0; j < 7; j++) {
      if (j == 0){
        mvAry[mvAry.length]  = '  <td style="cursor:hand;color:' + calendar.colors["sun_word"] + ';"></td>';
      } else if(j == 6) {
        mvAry[mvAry.length]  = '  <td style="cursor:hand;color:' + calendar.colors["sat_word"] + ';"></td>';
      } else {
        mvAry[mvAry.length]  = '  <td style="cursor:hand;background-color:#FF0000"></td>';
      }
    }
    mvAry[mvAry.length]  = '    </tr>';
  }
  mvAry[mvAry.length]  = '      <tr style="background-color:' + calendar.colors["input_bg"] + ';">';
  mvAry[mvAry.length]  = '      </tr>';
  mvAry[mvAry.length]  = '    </table>';
  mvAry[mvAry.length]  = '  </form>';
  this.panel.innerHTML = mvAry.join("");
  this.form = document.forms["calendarForm"];

  this.form.prevMonth.onclick = function () {calendar.goPrevMonth(this);}
  this.form.nextMonth.onclick = function () {calendar.goNextMonth(this);}

  //this.form.calendarClear.onclick = function () {calendar.dateControl.value = "";calendar.hide();}
  //this.form.calendarClose.onclick = function () {calendar.hide();}
  this.form.calendarYear.onchange = function () {calendar.update(this);}
  this.form.calendarMonth.onchange = function () {calendar.update(this);}

  this.form.calendarYearIpt.onclick = function () {calendar.showYearSelect();}
  this.form.calendarMonthIpt.onclick = function () {calendar.showMonthSelect();}
  /*
  this.form.calendarToday.onclick = function () {
    var today = new Date();
    calendar.date = today;
    calendar.year = today.getFullYear();
    calendar.month = today.getMonth();
    calendar.changeSelect();
    calendar.bindData();
    calendar.dateControl.value = today.format(calendar.dateFormatStyle);
    calendar.hide();
  }
  */

}

//年份下拉框绑定数据

Calendar.prototype.bindYear = function() {
  var cy = this.form.calendarYear;
  cy.length = 0;
  for (var i = this.beginYear; i <= this.endYear; i++){
    cy.options[cy.length] = new Option(i + Calendar.language["year"][this.lang], i);
  }
}

//年份输入框绑定数据

Calendar.prototype.bindYearIpt = function() {
  var cyit = this.form.calendarYearIpt;
  cyit.value = this.date.getFullYear();
}

//月份下拉框绑定数据

Calendar.prototype.bindMonth = function() {
  var cm = this.form.calendarMonth;
  cm.length = 0;
  for (var i = 0; i < 12; i++){
    cm.options[cm.length] = new Option(Calendar.language["months"][this.lang][i], i);
  }
}

//月份输入框绑定数据

Calendar.prototype.bindMonthIpt = function() {
  var cmit = this.form.calendarMonthIpt;
  cmit.value = Calendar.language["months"][this.lang][this.date.getMonth()];
}

//向前一月

Calendar.prototype.goPrevMonth = function(e){
  if (this.year == this.beginYear && this.month == 0){return;}
  this.month--;
  if (this.month == -1) {
    this.year--;
    this.month = 11;
  }
  this.date = new Date(this.year, this.month, 1);
  this.changeSelect();
  this.bindData();
}

//向后一月

Calendar.prototype.goNextMonth = function(e){
  if (this.year == this.endYear && this.month == 11){return;}
  this.month++;
  if (this.month == 12) {
    this.year++;
    this.month = 0;
  }
  this.date = new Date(this.year, this.month, 1);
  this.changeSelect();
  this.bindData();
}

//显示年select元素
Calendar.prototype.showYearSelect = function (){
  var cy = this.form.calendarYear;
  var cyit = this.form.calendarYearIpt;
  cy.style.display = "";
  cyit.style.display = "none";

}

//显示月select元素
Calendar.prototype.showMonthSelect = function (){
  var cm = this.form.calendarMonth;
  var cmit = this.form.calendarMonthIpt;
  cm.style.display = "";
  cmit.style.display = "none";
}

//隐藏年select元素
Calendar.prototype.hiddenYearSelect = function (){
  var cy = this.form.calendarYear;
  var cyit = this.form.calendarYearIpt;
  cy.style.display = "none";
  cyit.style.display = "";

}

//隐藏月select元素
Calendar.prototype.hiddenMonthSelect = function (){
  var cm = this.form.calendarMonth;
  var cmit = this.form.calendarMonthIpt;
  cm.style.display = "none";
  cmit.style.display = "";
}

//改变SELECT选中状态

Calendar.prototype.changeSelect = function() {
  var cy = this.form.calendarYear;
  var cm = this.form.calendarMonth;
  var cyit = this.form.calendarYearIpt;
  var cmit = this.form.calendarMonthIpt;
  for (var i= 0; i < cy.length; i++){
    if (cy.options[i].value == this.date.getFullYear()){
      cy[i].selected = true;
      break;
    }
  }
  cyit.value = this.date.getFullYear() + Calendar.language["yeaript"][this.lang];
  for (var i= 0; i < cm.length; i++){
    if (cm.options[i].value == this.date.getMonth()){
      cm[i].selected = true;
      break;
    }
  }
  cmit.value = Calendar.language["months"][this.lang][this.date.getMonth()];
  this.hiddenMonthSelect();
  this.hiddenYearSelect();
}

//更新年、月
Calendar.prototype.update = function (e){
  this.year  = e.form.calendarYear.options[e.form.calendarYear.selectedIndex].value;
  this.month = e.form.calendarMonth.options[e.form.calendarMonth.selectedIndex].value;
  this.date = new Date(this.year, this.month, 1);
  this.changeSelect();
  this.bindData();
}

//绑定数据到月视图
Calendar.prototype.bindData = function () {
  var calendar = this;
  var dateArray = this.getMonthViewArray(this.date.getYear(), this.date.getMonth());
  var tds = this.getElementById("calendarTable").getElementsByTagName("td");
  for(var i = 0; i < tds.length; i++) {
  //tds[i].style.color = calendar.colors["td_word_light"];
  tds[i].style.backgroundColor = calendar.colors["td_bg_out"];
    tds[i].onclick = function () {return;}
    tds[i].onmouseover = function () {return;}
    tds[i].onmouseout = function () {return;}
    if (i > dateArray.length - 1) break;
    tds[i].innerHTML = dateArray[i];
    if (dateArray[i] != "&nbsp;"){
      tds[i].onclick = function () {
        if (calendar.dateControl != null){
          calendar.dateControl.value = new Date(calendar.date.getFullYear(),
                                                calendar.date.getMonth(),
                                                this.innerHTML).format(calendar.dateFormatStyle);
        }
		//alert(calendar.dateControl.value);
		//alert(i);
		funcGetDate(calendar.dateControl.value);
		
        //calendar.hide();
      }

	  /*
	  if (tds[i].innerHTML == 3){
		  
		  tds[i].style.backgroundColor = calendar.colors["td_bg_over"];
	  }
	  */
		
		var now = new Date();
        var cur_year = now.getFullYear();       //年
        var cur_month = now.getMonth() + 1;     //月
        var cur_day = now.getDate();            //日
        var cur_date = cur_year + "-";
        if(cur_month < 10)
            cur_date += "0";
        cur_date += cur_month + "-";
        if(cur_day < 10)
            cur_date += "0";
        cur_date += cur_day;
		
		if(GetCookie('TeemsCalSelectDate')==null)
		{
			var selectDate = cur_date.toDate();	
		}
		else
		{
			var selectDate = GetCookie('TeemsCalSelectDate').toDate();	
		}
		//alert(calendar.date.getMonth());
		
		var selectMonth = selectDate.getMonth();
		var viewType = GetCookie('TeemsCalViewType');
		if(viewType == 3){
			if(calendar.date.getMonth() == selectMonth){
				tds[i].style.backgroundColor = calendar.colors["select_date"];
			}
		}
		//alert(GetCookie('TeemsCalSelectDate'));
		//alert(tmonth);

      tds[i].onmouseover = function () {
        this.style.backgroundColor = calendar.colors["td_bg_over"];
      }
      tds[i].onmouseout = function () {
        this.style.backgroundColor = calendar.colors["td_bg_out"];
      }
      if (new Date().format(calendar.dateFormatStyle) ==
          new Date(calendar.date.getFullYear(),
                   calendar.date.getMonth(),
                   dateArray[i]).format(calendar.dateFormatStyle)) {
        //tds[i].style.color = calendar.colors["cur_word"];
        tds[i].style.backgroundColor = calendar.colors["cur_bg"];
        tds[i].onmouseover = function () {
          this.style.backgroundColor = calendar.colors["td_bg_over"];
        }
        tds[i].onmouseout = function () {
          this.style.backgroundColor = calendar.colors["cur_bg"];
        }
      }//end if
    }
  }
}

//根据年、月得到月视图数据(数组形式)
Calendar.prototype.getMonthViewArray = function (y, m) {
  var mvArray = [];
  var dayOfFirstDay = new Date(y, m, 1).getDay();
  var daysOfMonth = new Date(y, m + 1, 0).getDate();
  for (var i = 0; i < 42; i++) {
    mvArray[i] = "&nbsp;";
  }
  for (var i = 0; i < daysOfMonth; i++){
    mvArray[i + dayOfFirstDay] = i + 1;
  }
  return mvArray;
}

//扩展 document.getElementById(id) 多浏览器兼容性 from meizz tree source
Calendar.prototype.getElementById = function(id){
  if (typeof(id) != "string" || id == "") return null;
  if (document.getElementById) return document.getElementById(id);
  if (document.all) return document.all(id);
  try {return eval(id);} catch(e){ return null;}
}

//扩展 object.getElementsByTagName(tagName)
Calendar.prototype.getElementsByTagName = function(object, tagName){
  if (document.getElementsByTagName) return document.getElementsByTagName(tagName);
  if (document.all) return document.all.tags(tagName);
}

//取得HTML控件绝对位置
Calendar.prototype.getAbsPoint = function (e){
  var x = e.offsetLeft;
  var y = e.offsetTop;
  while(e = e.offsetParent){
    x += e.offsetLeft;
    y += e.offsetTop;
  }
  return {"x": x, "y": y};
}

//显示日历
Calendar.prototype.show = function (dateControl, popControl) {
  if (dateControl == null){
    throw new Error("arguments[0] is necessary")
  }
  this.dateControl = dateControl;
  if (dateControl.value.length > 0){
  this.date = new Date(dateControl.value.toDate());
  this.year = this.date.getFullYear();
  this.month = this.date.getMonth();
    this.changeSelect();
    this.bindData();
  }
  if (popControl == null){
    popControl = dateControl;
  }
  var xy = this.getAbsPoint(popControl);
  this.panel.style.left = xy.x + "px";
  this.panel.style.top = (xy.y + dateControl.offsetHeight) + "px";
  this.setDisplayStyle("select", "hidden");
  this.panel.style.visibility = "visible";
}

//隐藏日历
Calendar.prototype.hide = function() {
  this.setDisplayStyle("select", "visible");
  this.panel.style.visibility = "hidden";
}

//设置控件显示或隐藏

Calendar.prototype.setDisplayStyle = function(tagName, style) {
  var tags = this.getElementsByTagName(null, tagName)
  for(var i = 0; i < tags.length; i++) {
    if (tagName.toLowerCase() == "select" &&
       (tags[i].name == "calendarYear" ||
      tags[i].name == "calendarMonth")){
      continue;
    }
    tags[i].style.visibility = style;
  }
}

function GetCookieVal(offset){
	var endstr = document.cookie.indexOf (";", offset);
	if (endstr == -1)
	endstr = document.cookie.length;
	return unescape(document.cookie.substring(offset, endstr));
}

function SetCookie(name, value ,expiresDate){
	var expdate = new Date();
	var argv = SetCookie.arguments;
	var argc = SetCookie.arguments.length;
	var expires = (argc > 2) ? argv[2] : null;
	var path = (argc > 3) ? argv[3] : null;
	var domain = (argc > 4) ? argv[4] : null;
	var secure = (argc > 5) ? argv[5] : false;
	if(expiresDate!=null) expdate.setTime(expdate.getTime() + ( expiresDate * 1000 * 3600 * 24));
	document.cookie = name + "=" + escape (value) +((expiresDate == null) ? "" : ("; expires="+ expdate.toGMTString()))
	+((path == null) ? "" : ("; path=" + path)) +((domain == null) ? "" : ("; domain=" + domain))
	+((secure == true) ? "; secure" : "");
}

function DelCookie(name){
	var exp = new Date();
	exp.setTime (exp.getTime() - 1);
	var cval = GetCookie (name);
	document.cookie = name + "=" + cval + "; expires="+ exp.toGMTString();
}

function GetCookie(name){
	var arg = name + "=";
	var alen = arg.length;
	var clen = document.cookie.length;
	var i = 0;
	while (i < clen){
		var j = i + alen;
		if (document.cookie.substring(i, j) == arg)
		return GetCookieVal (j);
		i = document.cookie.indexOf(" ", i) + 1;
		if (i == 0) break;
	}
	return null;
}

document.write('<div id="calendarPanel" style="position:  static ;visibility: hidden;z-index: 9999;background-color: #FFFFFF;border: 1px solid #99CCFF;width:100%;padding:2px;margin-left:5px;"></div>');
//var calendar = new Calendar();
//calendar.show(dateControl, popControl);
-->