/*
 * LazyBeautifyTable
 * 表格美化
 */

(function($) {

    /*
     * 默认参数
     */
    $.LazyBeautifyTableSettings = {

        //表格行划过效果
        hoverClass: 'tableline-hover',

        //是否显示划过效果
        showHoverEffect: true,

        //是否显示行交替效果
        showToggleLineEffect: true,

        //默认排序字段
        defaultSortField: "",

        //默认排序方式(desc、asc)
        defaultSortOrder: "",

        //按钮容器
        buttonsWrap: false,

        //按钮信息数组
        buttons: false,

        //回调函数
        callback: false,

        headPadding: "5px",

        bodyPadding: "5px"

    };

    $.fn.extend({

        LazyBeautifyTable: function(settings) {

            //合并默认参数
            $.extend($.LazyBeautifyTableSettings, settings);

            return this.each(function() {
                var self = $(this);

                /*
                 * 按钮
                 */
                if ($.LazyBeautifyTableSettings.buttons) {

                    //
                    if ($.LazyBeautifyTableSettings.buttonsWrap) {
                        $($.LazyBeautifyTableSettings.buttonsWrap).empty();
                    }

                    $.each($.LazyBeautifyTableSettings.buttons, function(index, value) {
                        switch (value.type) {

                            //查询按钮无需处理，在LazyGrid中已经处理
                            case "search":
                                break;

                                //全选按钮
                            case "checkall":
                                //增加全选checkbox
                                self.find("thead>tr>td:first").html("<input style='margin-top:4px;' type='checkbox' id='checkall'/>");

                                //剔除disabled的checkbox
                                var checkboxObj = ":checkbox[name=" + value.name + "]:not([disabled])";
                                //全选
                                self.find("#checkall").click(function() {
                                    if (this.checked) {
                                        $(checkboxObj).attr("checked", "checked");
                                    } else {
                                        $(checkboxObj).removeAttr("checked");
                                    }

                                    //美化复选框
                                    self.find(":checkbox").LazyBeautifyForm();
                                });
                                //反选
                                self.find(checkboxObj).click(function() {
                                    if (this.checked) {
                                        if (self.find(checkboxObj).filter(function() {
                                            return !this.checked;
                                        }).length == 0) {
                                            self.find("#checkall").attr("checked", "checked");
                                        }
                                    } else {
                                        self.find("#checkall").removeAttr("checked");
                                    }
                                    self.find(":checkbox").LazyBeautifyForm();
                                });
                                break;

                                //其他按钮
                            default:
                                var $button = $("<input type='button' style='margin-left:10px;' class='btn btn-primary' value='" + value.text + "'/>").click(function() {
                                    var callbackStr = 'value.callback(';
                                    if (value.param) {
                                        var param;
                                        if ($.type(value.param) === "function") {
                                            param = value.param();
                                        } else {
                                            param = value.param;
                                        }
                                        if ($.type(param) === "array") {
                                            $.each(param, function(index, value) {
                                                callbackStr += "\'" + value + "\',";
                                            });
                                            callbackStr = callbackStr.substring(callbackStr.length - 1, 0);
                                        } else {
                                            callbackStr += "\'" + param + "\'";
                                        }
                                    }
                                    callbackStr += ")";
                                    eval(callbackStr);
                                });
                                //当有容器时，将按钮写入容器，否则写在表格下面
                                if ($.LazyBeautifyTableSettings.buttonsWrap) {
                                    $button.appendTo($($.LazyBeautifyTableSettings.buttonsWrap));
                                } else {
                                    $button.insertAfter(self);
                                }
                                break;
                        }
                    });
                }

                /*
                 * 设置表格样式
                 */

                //去除原表格边框
                
                self.addClass("lazy_beautify_table").css("border", "none");

                /*
                 * 处理表头
                 */

                //表头对象
                if (self.find("thead").length > 0) {
                    var $theadTrObj = self.find("thead:first>tr");

                    $theadTrObj.addClass("table-header-center");

                }

                self.find("tbody>tr").addClass("tableline").hover(function() {
                    $(this).addClass("tableline-hover");
                }, function() {
                    $(this).removeClass("tableline-hover");
                });

                /*
                 * 排序
                 */
                if (self.find("thead").length > 0) {
                    //默认排序
                    if ($.LazyBeautifyTableSettings.defaultSortField) {
                        $theadTrObj.find("td").filter(function() {
                            return $(this).attr("field") == $.LazyBeautifyTableSettings.defaultSortField;
                        }).addClass("table-sort-hover").append(function() {
                            var imgSrc = $.LazyBeautifyTableSettings.defaultSortOrder == "desc" ? "" + $.LazyBeautifyTableSettings.theme + "images/grid/table-sort-down.png" : "" + $.LazyBeautifyTableSettings.theme + "images/grid/table-sort-up.png";
                            var left = $(this).width() - 10;
                            return "<img class='sort-arrow' src=" + imgSrc + " border='0' style='float:right;margin-right:2px;margin-top:-15px'/>";
                        });
                    }

                    //排序列划过效果

                    $theadTrObj.find('td[field]').hover(function() {
                        if ($(this).find("img[class='sort-arrow']").length == 0) {
                            $(this).addClass("table-sort-hover").append(function() {
                                var left = $(this).width() - 10;
                                return "<img class='sort-arrow-double' src=" + $.LazyBeautifyTableSettings.theme + "images/grid/table-sort-up-down.png border='0' style='float:right;margin-right:2px;margin-top:-19px;'/>";
                            });
                        }
                    }, function() {
                        if ($(this).find("img[class='sort-arrow-double']").length != 0) {
                            $(this).removeClass("table-sort-hover").find(".sort-arrow-double").remove();
                        }
                    });
                    /*
                     * 非LazyGrid生成的表格排序
                     */

                    //默认排序
                    if (self.find("thead").length > 0) {
                        $theadTrObj.find('td').filter(function() {
                            return $(this).find("a[class='tabletitle']").length > 0 && $(this).find("img").length > 0;
                        }).addClass("table-sort-hover").append(function() {
                            var $tableTileObj = $(this).find("a[class='tabletitle']");
                            var href = $tableTileObj.attr("href");
                            if ($tableTileObj.find("img").length > 0) {
                                $tableTileObj.find("img").remove();
                            } else if ($tableTileObj.next("img").length > 0) {
                                $tableTileObj.next("img").remove();
                            } else if ($tableTileObj.prev("img").length > 0) {
                                $tableTileObj.prev("img").remove();
                            }

                            var index = href.indexOf("sens");
                            var sens;
                            if (index != -1) {
                                sens = href.substr(index + 5, 1);
                            }
                            var imgSrc = sens == 1 ? "" + $.LazyBeautifyTableSettings.theme + "images/grid/table-sort-down.png" : "" + $.LazyBeautifyTableSettings.theme + "images/grid/table-sort-up.png";
                            var left = $(this).width() - 10;
                            return "<img class='sort-arrow' src=" + imgSrc + " border='0' style='float:right;margin-right:2px;margin-top:-15px'/>";
                        });
                    }

                    //排序列划过效果
                    self.find('thead:first td').hover(function() {
                        $(this).find("a").css("color", "black");
                        if ($(this).find("a[class='tabletitle']").length > 0 && $(this).find("img[class='sort-arrow']").length == 0) {
                            $(this).addClass("table-sort-hover").append(function() {
                                var left = $(this).width() - 10;
                                return "<img class='sort-arrow-double' src=" + $.LazyBeautifyTableSettings.theme + "images/grid/table-sort-up-down.png border='0' style='float:right;margin-right:2px;margin-top:-19px'/>";
                            });
                        }
                        return false;
                    }, function() {
                        if ($(this).find("img[class='sort-arrow-double']").length != 0) {
                            $(this).removeClass("table-sort-hover").children("img").remove();
                        }
                        return false;
                    }).click(function() {
                        if ($(this).find("a[class='tabletitle']").length > 0) {
                            window.location.href = $(this).find("a[class='tabletitle']").attr("href");
                        }
                    });
                    //排序按钮鼠标按下效果
                    self.find('thead:first').find(".table-sort-hover").live('mousedown', function() {
                        $(this).removeClass().addClass("table-sort-click");
                    });
                    //排序按钮鼠标抬起效果
                    self.find('thead:first').find(".table-sort-click").live('mouseup', function() {
                        $(this).removeClass().addClass("table-sort-hover");
                    });
                }
                //回调函数
                if ($.LazyBeautifyTableSettings && $.LazyBeautifyTableSettings.callback) {
                    $.LazyBeautifyTableSettings.callback();
                }
            });
        }
    });
})(jQuery);
