(function($) {

	$.LazyGridSettings = {
		pagination : {
			pageIndex : 0, //分页起始索引(默认0)
			pageCount : 12//每页条数(默认12)
		},
		hoverClass : 'tableline-hover', //列表划过效果
		showHoverEffect : true, //是否显示划过效果
		showToggleLineEffect : true, //是否显示行交替效果
		showSearchCondition : true, //是否展示查询条件
		callback : {//回调函数
			complete : ''//列表加载完成后调用
		},
		customParam : false
	}

	var quicksortObj;

	//发送ajax请求函数
	function SendRequest() {
		$.ajax({
			type : 'POST',
			data : CreateParam(),
			url : $.LazyGridSettings.url
		}).done(function(result) {

			//解析服务端返回的数据
			var parsedData = $.parseJSON(result);
			if (parsedData.customParam && parsedData.customParam != "") {
				$.LazyGridSettings.customParam = parsedData.customParam;
			}
			//查询条件
			if ($.LazyGridSettings.showSearchCondition) {
				var searchStr = "";
				if (parsedData.searchParam && parsedData.searchParam != "") {
					$(".searchConditionTable").show();
					searchStr += "<div><table class='search-condition-delete' border='0' cellpadding='0' cellspacing='0'><tr><td class='search-button-left'></td><td nowrap='nowrap' class='search-button-center' style='color:#000000;'>" + LazyGridLang.AllConditions + "</td><td nowrap='nowrap' class='search-button-delete'></td></tr></table></div>";
					$.each(parsedData.searchParam, function(index, value) {
						searchStr += "<div><table class='search-condition' nowrap='nowrap' field='" + value.field + "' text='" + value.text + "' value='" + value.value + "' border='0' cellpadding='0' cellspacing='0'><tr><td class='search-button-left' nowrap='nowrap'></td><td nowrap='nowrap' class='search-button-center'>" + value.title + "</td><td class='search-button-center' nowrap='nowrap'>" + value.op + "</td><td nowrap='nowrap' class='search-button-center'><div class='textWrap' title='" + value.text + "' style='text-overflow:ellipsis;white-space:nowrap;overflow:hidden;'>" + value.text + "</div></td><td nowrap='nowrap' class='search-button-delete'></td></tr></table></div>";
					});
				} else {
					$(".searchConditionTable").hide();
				}
				$(".searchConditionWrap").html(searchStr);

				//对查询条件超长的控制
				$(".searchConditionWrap").find(".textWrap").filter(function() {
					if ($(this).width() > 300) {
						$(this).width(300);
					}
				});
			}

			//更新快速筛选
			if (quicksortObj) {
				quicksortObj.Update();
			}

			/*********************************************************************
			 * 定义拼音检索
			 ********************************************************************/
			if ($.LazyGridSettings.pinyinsearch) {
				$(".lazyGrid .pinYinSearchWrap").LazyPinYinSearch({
					callback : pinYinSearchCallBack,
					defaultValue : $("#pinYinSearchParam").val(),
					_width : $(".pinYinSearchWrap").width()
				});
			}
			if (parsedData.pagingParam == 0) {//如果返回的数据为空，则显示暂无数据提示
				var left = $(".lazyGrid .bodyWrap").offset().left;
				var width = $(".lazyGrid .bodyWrap").width();
				$(".lazyGrid .bodyWrap").html($('<img src="' + $.LazyGridSettings.theme + 'images/message/nodata.png"/>').css({
					"margin-top" : "10px",
					"margin-left" : left + width / 2 - 179
				}));
				$(".buttonWrap").empty();
				$(".paginationWrap").empty();
			} else {

				$(".lazyGrid .bodyWrap").html(parsedData.htmlStr);

				//处理排序
				var sortParam = $("#sortParam").val();
				var sortOrder = $.LazyGridSettings.defaultSortOrder;
				var sortField = $.LazyGridSettings.defaultSortField;
				if ($.trim(sortParam) != "") {
					var sortParmSplit = sortParam.split("*");
					if (sortParmSplit.length == 2) {
						sortOrder = sortParmSplit[1];
						sortField = sortParmSplit[0];
					}
				}

				// 美化表格
				$(".lazyGrid .bodyWrap table:first").LazyBeautifyTable({
					buttons : $.LazyGridSettings.buttons,
					buttonsWrap : ".buttonWrap",
					callback : $.LazyGridSettings.callback.complete,
					hoverClass : $.LazyGridSettings.hoverClass,
					showHoverEffect : $.LazyGridSettings.showHoverEffect,
					showToggleLineEffect : $.LazyGridSettings.showToggleLineEffect,
					theme : $.LazyGridSettings.theme,
					defaultSortOrder : sortOrder,
					defaultSortField : sortField
				});

				//分页
				$(".lazyGrid .paginationWrap").Pagination(parsedData.pagingParam, {
					items_per_page : $.LazyGridSettings.pagination.pageCount,
					current_page : parseInt($("#paginationOffset").val()),
					callback : paginationCallBack
				});

				//美化控件
				$(".lazyGrid").find(":input,a[type='button'],a[class='button']").LazyBeautifyForm();

			}

		}).fail(function() {
			alert("Error:Send Request Ajax Fail");
		});
	}

	function ResetSearchParam() {
		$(".searchConditionTable").hide();
		$("#searchParam").val("");
	}

	function ResetQuickSortParam() {
		$("#quickSortParam").val("");
		$(".quicksort .center").html(LazyGridLang.All);
	}

	function ResetPinYinSearchParam() {
		$("#pinYinSearchParam").val("all");

		//移除已经选中的
		$(".pinyinsearch .index").filter(function() {
			return $(this).hasClass("selected-center");
		}).removeClass("selected-center").next().removeClass("selected-border").addClass("split").end().prev().removeClass("selected-border").addClass("split");

		//选中全部
		$(".pinyinsearch .index[param=all]").addClass("selected-center").prev().addClass("selected-border").end().next().addClass("selected-border");
	}

	/*
	 * 快速筛选回调函数
	 * @param self object 快速筛选当前点击对象
	 */
	function quickSortCallBack(self) {
		//清空拼音检索参数
		ResetPinYinSearchParam();

		//清空查询参数
		ResetSearchParam();

		//重置分页参数
		$("#paginationOffset").val(0);

		if ($.type(self) === "string") {
			$("#quickSortParam").val(self);
		} else {
			if (self.attr("grouptype") == "2" || self.attr("grouptype") == "3") {
				$("#searchParam").val(self.attr("optionParam"));
			} else {
				$("#quickSortParam").val(self.attr("optionParam"));
			}
		}

		$("#op").val("quicksort");
		SendRequest();
	}

	/*
	 * 拼音检索回调函数
	 * @param self object 拼音检索当前点击对象
	 */
	function pinYinSearchCallBack(key, value) {
		$("#pinYinSearchParam").val(key);
		$("#paginationOffset").val(0);
		$("#op").val("pinyinsearch");
		SendRequest();
	}

	/*
	 * 分页回调函数
	 * @param pageIndex string 当前页索引
	 */
	function paginationCallBack(pageIndex) {
		$("#paginationOffset").val(pageIndex);
		SendRequest();
	}

	/*
	 * 拼接所有参数
	 * @return 所有参数
	 */
	function CreateParam() {
		var paramArray = new Array();

		//快速筛选参数
		paramArray.push("quickSortParam=" + $("#quickSortParam").val());

		//拼音检索参数
		paramArray.push("pinYinSearchParam=" + $("#pinYinSearchParam").val());

		//分页参数-当前页
		paramArray.push("paginationOffset=" + $("#paginationOffset").val());

		//分页参数-每页数量
		paramArray.push("paginationRows=" + $.LazyGridSettings.pagination.pageCount);

		//排序参数
		paramArray.push("sortParam=" + $("#sortParam").val());

		//查询参数
		paramArray.push($("#searchParam").val());

		//操作类型参数
		paramArray.push("op=" + $("#op").val());

		//固定参数
		paramArray.push($("#dataParam").val());

		return paramArray.join("&");
	}


	$.fn.extend({
		LazyGrid : function(settings) {
			return this.each(function() {
				var self = $(this);

				//合并默认参数
				$.extend(true, $.LazyGridSettings, settings);

				//生成圆角边框
				var wrapHtmlArr = new Array();
				wrapHtmlArr.push('<div id="searchWrap" style="display:none;">');
				wrapHtmlArr.push('<div style="background: url(/images/8/icons/line.png) no-repeat center;height: 4px;margin-bottom: 10px;"></div>');
				wrapHtmlArr.push('<div id="searchDiv"></div>');
				wrapHtmlArr.push('<div class="bg-split" style="margin: 10px 0 10px 0"></div>');
				wrapHtmlArr.push('<div style="float: right;"><input type="button" value="' + EOlang.msgSubmit + '" id="searchSubmit" /></div></div>');

				wrapHtmlArr.push('<img id="loading" border="0" src="/images/8/icons/loading.gif" style="position:absolute;display:none;"/>');
				wrapHtmlArr.push('<table border="0" cellpadding="0" cellspacing="0" width="100%">');
				wrapHtmlArr.push('<tr height="10">');
				wrapHtmlArr.push('<td width="10" class="tablecornertopleft10"></td>');
				wrapHtmlArr.push('<td class="tablecornertopcenter10"></td>');
				wrapHtmlArr.push('<td width="10" class="tablecornertoprightt10"></td>');
				wrapHtmlArr.push('</tr>');
				wrapHtmlArr.push('<tr>');
				wrapHtmlArr.push('<td width="10" class="tablecornermiddleleft"></td>');
				wrapHtmlArr.push('<td class="tablecornermiddlecenter" valign="top">');

				wrapHtmlArr.push('<table class="lazyGrid" width="100%" border="0" cellpadding="0" cellspacing="0">');
				wrapHtmlArr.push('<tr><td id="topbar"><table style="table-layout: fixed;" width="100%" border="0" cellpadding="0" cellspacing="0"><tr><td class="quickSortWrap" align="left" valign="top" style="padding-right:10px;"></td><td class="pinYinSearchWrap" align="left" valign="top"></td><td width="10%" class="searchButtonWrap" align="right" valign="top"></td></tr></table></td></tr>');
				wrapHtmlArr.push('<tr><td style="padding:2px;"><table border="0" width="100%" cellpadding="0" cellspacing="0" class="searchConditionTable" style="display:none;"><tr><td width="60px" style="padding-left:15px;">' + LazyGridLang.SearchConditions + '：</td><td class="searchConditionWrap" style="padding:5px;" valign="top"></td></tr></table></td></tr>');
				wrapHtmlArr.push('<tr><td class="bodyWrap"></td></tr>');
				wrapHtmlArr.push('<tr><td class="bottomBar">');
				wrapHtmlArr.push('<table width="100%" border="0" cellpadding="0" cellspacing="0">');
				wrapHtmlArr.push('<tr><td class="buttonWrap"></td><td class="paginationWrap"></td></tr>');
				wrapHtmlArr.push('</table>');
				wrapHtmlArr.push('</td></tr>');
				wrapHtmlArr.push('</table>');

				wrapHtmlArr.push('<input type="hidden" id="sortParam"/>');
				wrapHtmlArr.push('<input type="hidden" id="pinYinSearchParam"/>');
				wrapHtmlArr.push('<input type="hidden" id="quickSortParam"/>');
				wrapHtmlArr.push('<input type="hidden" id="paginationOffset"/>');
				wrapHtmlArr.push('<input type="hidden" id="searchParam"/>');
				wrapHtmlArr.push('<input type="hidden" id="op"/>');
				wrapHtmlArr.push('<input type="hidden" id="dataParam"/>');

				wrapHtmlArr.push('</td>');
				wrapHtmlArr.push('<td width="10" class="tablecornermiddleright"></td>');
				wrapHtmlArr.push('</tr>');
				wrapHtmlArr.push('<tr height="10">');
				wrapHtmlArr.push('<td width="10" class="tablecornerbottomleft"></td>');
				wrapHtmlArr.push('<td class="tablecornerbottomcenter"></td>');
				wrapHtmlArr.push('<td width="10" class="tablecornerbottomright" ></td>');
				wrapHtmlArr.push('</tr>');
				wrapHtmlArr.push('</table>');

				self.html(wrapHtmlArr.join(''));

				/*********************************************************************
				 * 处理默认参数
				 ********************************************************************/
				//默认排序参数
				$("#sortParam").val($.LazyGridSettings.defaultSortField + "*" + $.LazyGridSettings.defaultSortOrder);

				//默认分页参数-当前页
				$("#paginationOffset").val($.LazyGridSettings.pagination.pageIndex);

				//默认拼音检索参数
				if ($.LazyGridSettings.pinyinsearch) {
					if ($.LazyGridSettings.pinyinsearch.defaultValue) {
						$("#pinYinSearchParam").val($.LazyGridSettings.pinyinsearch.defaultValue);
					} else {
						$("#pinYinSearchParam").val("all");
					}
				}

				//默认快速筛选参数
				var quicksortDefault = $.LazyGridSettings.quicksort && $.LazyGridSettings.quicksort.defaultValue ? $.LazyGridSettings.quicksort.defaultValue : "all";
				$("#quickSortParam").val(quicksortDefault);

				$("#op").val("init");

				/*********************************************************************
				 * 处理固定参数
				 ********************************************************************/
				if ($.LazyGridSettings.data) {
					var dataParam = "";
					$.each($.LazyGridSettings.data, function(index, value) {
						if (dataParam == "") {
							dataParam = index + "=" + value;
						} else {
							dataParam += "&" + index + "=" + value;
						}
					});
					$("#dataParam").val(dataParam);
				}

				/*********************************************************************
				 * 定义快速筛选
				 ********************************************************************/

				if ($.LazyGridSettings.quicksort) {
					var defaults = {
						callback : quickSortCallBack,
						theme : $.LazyGridSettings.theme,
						defaultValue : quicksortDefault
					}
					$.extend(true, $.LazyGridSettings.quicksort, defaults);
					quicksortObj = $(".lazyGrid .quickSortWrap").LazyQuickSort($.LazyGridSettings.quicksort);
				}

				/*********************************************************************
				 * 初始化数据
				 ********************************************************************/
				SendRequest();

				/*********************************************************************
				 * 删除查询条件
				 ********************************************************************/
				$(".search-condition").die().live({
					'click' : function() {
						$("#op").val("");
						$(this).remove();
						var param = "";
						$(".search-condition").each(function() {
							var data = $(this).attr("value") == "undefined" ? $(this).attr("text") : $(this).attr("value") + "&" + $(this).attr("field") + "_text=" + $(this).attr("text");
							if (param == "") {
								param = $(this).attr("field") + "=" + data;
							} else {
								param += "&" + $(this).attr("field") + "=" + data;
							}
						});

						$("#searchParam").val(param);
						if ($(".search-condition").length == 0) {
							$(".quicksort .center").html(LazyGridLang.All);
							$(".searchConditionTable").hide();
						}
						SendRequest();
					}
				});

				/*********************************************************************
				 * 删除所有查询条件
				 ********************************************************************/
				$(".search-condition-delete").die().live({
					'click' : function() {
						ResetSearchParam();
						$(".quicksort .center").html(LazyGridLang.All);
						SendRequest();
					}
				});

				/*********************************************************************
				 * 发送查询请求
				 ********************************************************************/
				$("#searchWrap #searchSubmit").click(function() {
					$("#paginationOffset").val($.LazyGridSettings.pagination.pageIndex);

					//查询参数
					var inputArray = new Array();
					$("#searchWrap form").find(":input:not(select)").each(function() {
						if ($(this).attr("name")) {
							inputArray.push($(this).attr("name") + "=" + $(this).val());
						}
					});
					$("#searchWrap form").find("select").each(function() {
						if ($(this).attr("name")) {
							inputArray.push($(this).attr("name") + "=" + $(this).find('option:selected').val());
							inputArray.push($(this).attr("name") + "_text=" + $(this).find('option:selected').text());
						}
					});

					$("#searchParam").val(inputArray.join("&"));

					//清空拼音检索参数
					ResetPinYinSearchParam();

					//清空快速筛选参数
					ResetQuickSortParam();

					$("#op").val("search");
					SendRequest();
					hs.close();
				});
				/*********************************************************************
				 * 生成查询按钮
				 ********************************************************************/
				if ($.LazyGridSettings.buttons) {
					$.each($.LazyGridSettings.buttons, function(index, value) {
						if (value.type == "search") {
							$(".lazyGrid .searchButtonWrap").html($("<table border='0' cellpadding='0' cellspacing='0'><tr><td><a type='button' img='/images/8/icons/search.png' href='/inc/plugins/searchwrap.php'>" + LazyGridLang.Search + "</a></td></tr></table>").click(function() {

								//加载查询页面
								$.ajax({
									url : value.url,
									async : false,
									cache : false
								}).done(function(result) {
									$("#searchWrap #searchDiv").html(result);
									$("#searchWrap").find(":input,a[type='button'],a[class='button']").LazyBeautifyForm();
								});
								var caption = value.caption ? value.caption : "";

								if (hs) {

									return hs.htmlExpand(this, {
										maincontentId : 'searchWrap',
										align : 'center',
										captionText : '<span style="color:#1d93d3;font-weight:bold;">&nbsp;' + caption + '</span>',
										width : value.width,
										height : value.height,
										captionOverlay : {
											position : 'toppanel'
										}
									});

								} else {
									alert("Error:hs undefined");
								}
							}));
							return false;
						}
					});
					//插入显示错误新的容器
					hs.Expander.prototype.onAfterExpand = function(sender) {
						var searchWrap = '<span style="width:110px;color:red;display:none;z-index:99999;" id="searchCheck">' + LazyGridLang.ErrorInput + '</span>';
						$(".highslide-caption").append(searchWrap);
						var marginLeft = Math.floor((sender.width - 110) / 2) - $("#searchCheck").prev().width();
						$("#searchCheck").css("margin-left", marginLeft);
					}
				}

				//查询条件禁止输入特殊字符
				$("#searchWrap").find(":text").live('keyup', function(event) {
					var value = $.trim($(this).val());
					if (value != "") {
						var reg = $(this).attr("check") ? eval($(this).attr("check")) : /[^a-zA-Z0-9\u4e00-\u9fa5]+/g;

						if (reg.test(value)) {
							$(this).val(value.replace(reg, ""));
							$("#searchCheck").show().fadeOut(1500);
							return false;
						}
					}
				});
				/*********************************************************************
				 * ajax请求等待
				 ********************************************************************/
				$("#loading").ajaxStart(function() {
					//等待加载图片显示在屏幕中央
					var $bodyObj = $("body");
					var left = $bodyObj.offset().left + $bodyObj.width() / 2;
					var top = $bodyObj.offset().top + $bodyObj.height() / 2;
					$(this).css({
						"left" : left + "px",
						"top" : top + "px",
						"z-index" : 99999
					}).show();

					//ajax加载时，禁用删除查询条件
					$(".search-condition,.search-condition-delete").attr("disabled", "disabled");
				}).ajaxStop(function() {
					$(this).hide();
					$(".search-condition,.search-condition-delete").removeAttr("disabled");
				});
				/*********************************************************************
				 * 排序
				 ********************************************************************/
				$(".lazyGrid table .table-sort-hover").live('click', function() {
					var sortOrder = "";
					if ($(this).children("img").attr("src")) {
						var imgSrc = $(this).children("img").attr("src");

						if (imgSrc.substring(imgSrc.length - 6) == "up.png") {
							sortOrder = "desc";
						} else {
							sortOrder = "asc";
						}
					} else {
						sortOrder = "desc";
					}

					var field = $.trim($(this).attr("field"));
					$("#sortParam").val(field + "*" + sortOrder);
					SendRequest();
				});
			});
		},
		Reload : function() {
			SendRequest();
		},
		CustomParamResult : function() {
			var customParam = $.LazyGridSettings.customParam;
			return customParam;
		}
	});
})(jQuery)
