/**
 * 操作cookie方法集合
 */
jQuery.LazyCookieUtils = {
    get: function(name) {
        var cookieName = encodeURIComponent(name) + '=',
            cookieStart = document.cookie.indexOf(cookieName),
            cookieValue = null;

        if (cookieStart > -1) {
            var cookieEnd = document.cookie.indexOf(";", cookieStart);
            if (cookieEnd == -1) {
                cookieEnd = document.cookie.length;
            }
            cookieValue = decodeURIComponent(document.cookie.substring(cookieStart + cookieName.length, cookieEnd));
        }
        return cookieValue;
    },
    set: function(name, value, expires, path, domain, secure) {
        var cookieText = encodeURIComponent(name) + "=" + encodeURIComponent(value);

        if (expires instanceof Date) {
            cookieText += "; expires=" + expirse.toGMTString();
        }
        if (path) {
            cookieText += "; path=" + path;
        }
        if (domain) {
            cookieText += "; domain=" + domain;
        }
        if (secure) {
            cookieText += "; secure=" + secure;
        }
        document.cookie = cookieText;
    },
    unset: function(name, path, domain, secure) {
        this.set(name, '', new Date(0), path, domain, secure);
    },
};
/*
 * 格式化模板数据
 */
jQuery.LazyFormatTemplate = function(template, dataObj) {
    if (!template) {
        return dataObj;
    }
    var templateStr = template;
    if (jQuery.type(template) === "function") {
        templateStr = template(dataObj);
    }
    if (templateStr) {
        return templateStr.replace(/{.+?}/gi, function(regHtml) {
            var key = regHtml.replace(/{|}/gi, "");
            return dataObj[key];
        });
    } else {
        return templateStr === undefined ? "" : templateStr;
    }
};

/**
 * 获取字符串长度 中文2 英文1
 * @param {[type]} str [description]
 */
jQuery.LazyGetStringLength = function(str) {
    var realLength = 0,
        len = str.length,
        charCode = -1;
    for (var i = 0; i < len; i++) {
        charCode = str.charCodeAt(i);
        if (charCode >= 0 && charCode <= 128) {
            realLength += 1;
        } else {
            realLength += 2;
        }
    }
    return realLength;
};
/*
 * 显示隐藏
 *
 * 依赖 font-awesome
 */
(function($) {
    var methods = {
        init: function(options) {
            //默认参数
            var settings = $.extend({
                //是否自动隐藏
                autoHide: false,
                //显示提示文字
                showTip: LazypluginsArgu.LazypluginsShow,
                //隐藏提示文字
                hideTip: LazypluginsArgu.LazypluginsHide,
                /**
                 * 回调函数
                 */
                //显示
                onAfterShow: $.noop,
                //隐藏
                onAfterHide: $.noop
            }, options);
            return this.each(function() {
                var $this = $(this),
                    cookieKey = window.location.host + window.location.pathname + '_LazyToggle', //页面url+插件名(不含传参)
                    isShow;
                $this.data({
                    lazyToggleSettings: settings
                });
                $this.attr("title", settings.hideTip).addClass("lazy_toggle").html('<div class="icon_wrap"><i class="fa fa-angle-left"></i></div>');
                //获取cookie值
                isShow = $.LazyCookieUtils.get(cookieKey);
                if (isShow !== null) {
                    if (isShow === "1") {
                        $this.LazyToggle("show");
                    } else {
                        $this.LazyToggle("hide");
                    }
                } else {
                    // 没有cookie值时，使用配置
                    settings.autoHide ? $this.LazyToggle("hide") : $this.LazyToggle("show");
                }
                // 绑定点击事件
                $this.on({
                    click: function() {
                        // 切换状态
                        $this.data("isShow") ? $this.LazyToggle("hide") : $this.LazyToggle("show");
                        // 保存状态到cookie中
                        $.LazyCookieUtils.set(cookieKey, $this.data("isShow") ? "1": "0");
                    }
                });
            });
        },
        show: function() {
            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyToggleSettings");
                $this.attr("title", settings.hideTip).find("i").removeClass("fa-angle-right").addClass("fa-angle-left");
                settings.onAfterShow.call(this);
                $this.data("isShow", true);
            });
        },
        hide: function() {
            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyToggleSettings");
                $this.attr("title", settings.showTip).find("i").removeClass("fa-angle-left").addClass("fa-angle-right");
                settings.onAfterHide.call(this);
                $this.removeData("isShow");
            });
        }
    };
    $.fn.LazyToggle = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazyToggle');
        }
    };
})(jQuery);
/*
 * 筛选
 */
(function($) {
    var methods = {
        init: function(options) {
            var settings = $.extend(true, {
                common: {
                    template: "{title}",
                    dataSource: false
                },
                more: {
                    dataSource: false
                },
                /**
                 * 回调函数
                 */
                onClick: $.noop
            }, options);
            return this.each(function() {
                var self = this,
                    $this = $(this);
                $this.data("lazyFilterSettings", settings);
                $this.addClass("lazy_filter");
                if (settings.common.dataSource) {
                    $this.prepend('<ul class="lazy_filter_ul"/>');
                    if ($.type(settings.common.dataSource) == "string") {
                        $.ajax({
                            url: settings.common.dataSource,
                            data: settings.common.param
                        }).done(function(result) {
                            if (result) {
                                var parsedData = $.parseJSON(result);
                                methods._loadCommonList.call(self, parsedData);
                            }
                        }).fail(function() {});
                    } else {
                        methods._loadCommonList.call(this);
                    }
                }
                if (settings.more.dataSource) {
                    var htmlStr = [];
                    htmlStr.push('<select class="lazy_filter_select"><option value="-1">' + settings.more.header + '</option>');
                    $.each(settings.more.dataSource, function(index, value) {
                        if (value.subItems) {
                            htmlStr.push('<optgroup label="' + ($.type(value) === "object" ? value.title : value) + '">');
                            $.each(value.subItems, function(subIndex, subValue) {
                                htmlStr.push('<option value="' + ($.type(subValue) === "object" ? subValue.key : subIndex) + '">' + ($.type(subValue) === "object" ? subValue.title : subValue) + '</option>');
                            });
                            htmlStr.push('</optgroup>');
                        } else {
                            htmlStr.push('<option value="' + ($.type(value) === "object" ? value.key : index) + '">');
                            htmlStr.push($.type(value) === "object" ? value.title : value);
                            htmlStr.push('</option>');
                        }
                    });
                    htmlStr.push("</select>");
                    $this.append(htmlStr.join(''));
                }
                $this.on({
                    mouseenter: function() {
                        if ($(this).hasClass("current")) {
                            return false;
                        }
                        $(this).addClass("hover");
                    },
                    mouseleave: function() {
                        if ($(this).hasClass("current")) {
                            return false;
                        }
                        $(this).removeClass("hover");
                    },
                    click: function() {
                        $this.find(".filter_item").removeClass("current hover");
                        if ($this.find("select.lazy_filter_select").val() != -1) {
                            $this.find("select.lazy_filter_select").prepend('<option value="-1">' + settings.more.header + '</option>').selectpicker('val', -1).selectpicker('refresh');
                            $this.find("select.lazy_filter_select").selectpicker('setStyle', 'lazy_filter_select_active', "remove");
                        }
                        $(this).addClass("current");
                        settings.onClick.call(this, $(this).attr("data_key"));
                    }
                }, ".filter_item");
                $this.find("select.lazy_filter_select").selectpicker({
                    width: "auto",
                    height: "39px",
                    style: "lazy_filter_select_init"
                }).change(function() {
                    if ($(this).val() != -1) {
                        $this.find("select.lazy_filter_select option[value='-1']").remove();
                        $this.find("select.lazy_filter_select").selectpicker("refresh");
                        $this.find(".filter_item").removeClass("current hover");
                        $this.find("select.lazy_filter_select").selectpicker('setStyle', 'lazy_filter_select_active');
                        settings.onClick.call(this, $(this).val());
                    }
                });
            });
        },
        select: function(selectKey) {
            return this.each(function() {
                var $this = $(this);
                $this.find(".filter_item").removeClass("current hover");
                var $filterItem = $this.find(".filter_item[data_key='" + selectKey + "']");
                if ($filterItem.length > 0) {
                    $filterItem.addClass("current");
                } else {
                    $this.find("select.lazy_filter_select").selectpicker('val', selectKey).selectpicker('setStyle', 'lazy_filter_select_active');
                }
            });
        },
        /**
         * 加载常用筛选
         *
         **/
        _loadCommonList: function(dataInfor) {
            var $this = $(this),
                settings = $this.data("lazyFilterSettings"),
                template = settings.common.template,
                dataSource = dataInfor ? dataInfor : settings.common.dataSource,
                listArray = [],
                defaultKey;
            $.each(dataSource, function(index, value) {
                listArray.push('<li class="filter_item" data_key="' + value.key + '">');
                listArray.push($.LazyFormatTemplate(template, value));
                listArray.push('<li>');
                if (value.isDefault) {
                    defaultKey = value.key;
                }
            });
            $this.find(".lazy_filter_ul").html(listArray.join('')).end();
            if (defaultKey) {
                $this.LazyFilter("select", defaultKey);
            }
        }
    };
    $.fn.LazyFilter = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazyFilter');
        }
    };
})(jQuery);
/*
 * 表格插件
 */
(function($) {
    var methods = {
        init: function(options) {
            var settings = $.extend(true, {
                width: false,
                dataSource: false,
                /*
                 * 列配置 支持 数组、url、function(url和function最终需要返回数组类型，形式和数组配置一致)
                 */
                column: false,
                param: false,
                //隐藏列头
                hideHeader: false,
                //数据为空的时候隐藏列头
                hideHeaderWhenEmpty: true,
                page: {
                    itemsPerPage: 10,
                    currentPage: 0,
                    displayedPages: 5,
                    edges: 2,
                    perPageList: [10, 15, 20, 30, 40],
                    callback: $.noop,
                    mode: 'full' //full 、simple
                },
                buttons: {
                    buttonInfor: false,
                    filter: false,
                    showTrigger: "colorBlock" //colorBlock|row|both
                },
                batchButtons: false,
                sort: false,
                /**
                 * 回调函数
                 */
                //数据加载之后回调
                onAfterLoad: false,
                /**
                 * 插件保留配置
                 */
                _sortDescClass: "fa-sort-alpha-desc",
                _sortAscClass: "fa-sort-alpha-asc",
                _colors: ["#1EB1ED", "#94CE58", "#FDBF2D", "#FC6621", "#808080"]
            }, options);
            return this.each(function() {
                var $this = $(this);
                $this.addClass("lazy_table").data({
                    lazyTableSettings: settings,
                    lazyTableParam: settings.param
                });
                if (settings.width) {
                    $this.width(settings.width);
                }
                var tableHtml = ['<table class="lazy_table_table">'];
                var columnParamType = $.type(settings.column);
                if (columnParamType === "function") {
                    settings.column = settings.column.call(this);
                } else if (columnParamType === "string") {
                    $.ajax({
                        url: settings.column,
                        async: false
                    }).done(function(result) {
                        var parsedData = $.parseJSON(result);
                        settings.column = parsedData;
                    }).fail(function() {
                        alert("get column error");
                    });
                }
                //表格头
                if (!settings.hideHeader) {
                    tableHtml.push(methods._createHeaderHtml.call(this));
                }
                tableHtml.push('<tbody class="lazy_table_tbody"></tbody>');
                tableHtml.push('</table>');
                tableHtml.push('<div class="lazy_table_bottom">');
                //全选
                var isCheckAll = false;
                $.each(settings.column, function(index, value) {
                    if (value.key == "checkall") {
                        isCheckAll = true;
                        return false;
                    }
                });
                if (isCheckAll) {
                    tableHtml.push('<input class="lazy_table_checkall checkbox" type="checkbox"/>');
                }
                //批量操作
                if (settings.batchButtons) {
                    tableHtml.push('<div class="btn-group batch_button_wrap">');
                    $.each(settings.batchButtons, function(index, value) {
                        tableHtml.push('<button type="button" class="btn btn-primary batch_button" data_key="' + index + '">' + value.title + '</button>');
                    });
                    tableHtml.push('</div>');
                }
                //分页容器
                if (settings.page) {
                    tableHtml.push('<div class="pagination_wrap">');
                    if (settings.page.mode == 'full') {
                        tableHtml.push('<span>'+LazypluginsArgu.LazypluginsTotal+'<span class="total-count">0</span>'+LazypluginsArgu.LazypluginsLines+'</span>');
                    }
                    tableHtml.push('<a href="#" class="first" data-action="first">&laquo;</a>\
                                            <a href="#" class="previous" data-action="previous">&lsaquo;</a>\
                                            <span class="goto-page-wrap">\
                                                <input class="page" type="text" readonly="readonly" />\
                                                <span class="goto-button">&crarr;</span>\
                                            </span>\
                                            <a href="#" class="next" data-action="next">&rsaquo;</a>\
                                            <a href="#" class="last" data-action="last">&raquo;</a>');
                    if (settings.page.mode == 'full') {
                        tableHtml.push('<span>'+LazypluginsArgu.LazypluginsPerpage+'</span>\
                                            <span class="per-page-wrap">\
                                                <span class="per-page">' + settings.page.itemsPerPage + '</span>\
                                                <span class="arrow-wrap">\
                                                    <span class="page-arrow"></span>\
                                                </span></span>');
                    }
                    if (settings.page.mode == 'full') {
                        tableHtml.push('<ul class="page-count-list v show-top">');
                        for (var i = 0; i < settings.page.perPageList.length; i++) {
                            tableHtml.push('<li>' + settings.page.perPageList[i] + '</li>');
                        }
                        tableHtml.push('</ul>');
                    }
                    tableHtml.push('</div>');
                }
                tableHtml.push('</div>');
                $this.html(tableHtml.join(''));
                //加载中...
                var $loadingObj = $('<div>', {
                    'class': 'lazy_table_loading',
                    html: '<i class="fa fa-spinner fa-spin fa-2x"></i>'
                }).ajaxStart(function() {
                    if ($(this).data("load")) {
                        $(this).show();
                    }
                }).ajaxStop(function() {
                    if ($(this).data("load")) {
                        $(this).hide().removeData("load");
                    }
                });
                $this.prepend($loadingObj);
                //无数据提示
                $this.prepend('<div class="empty_tip">'+PaymentLang.paymentNoData+'</div>');
                /*
                 * 事件绑定
                 */
                //排序
                $this.on({
                    mouseenter: function() {
                        var $sortTitleWrapObj = $(this).find(".sort_title_wrap");
                        $(this).find(".sort_list_wrap").width($sortTitleWrapObj.width() + 5).show();
                        $sortTitleWrapObj.addClass("active").find(".title").addClass("active");
                    },
                    mouseleave: function() {
                        $(this).find(".sort_list_wrap").hide();
                        $(this).find(".sort_title_wrap").removeClass("active").find(".title").removeClass("active");
                    }
                }, ".sort_title_td");
                $this.find(".sort_list_wrap li").on({
                    click: function() {
                        var $sortIconObj = $(this).find("i");
                        //当前排序点击,显示相反排序
                        if ($sortIconObj.hasClass("active")) {
                            if ($sortIconObj.hasClass(settings._sortDescClass)) {
                                $sortIconObj.removeClass(settings._sortDescClass).addClass(settings._sortAscClass);
                            } else {
                                $sortIconObj.removeClass(settings._sortAscClass).addClass(settings._sortDescClass);
                            }
                        } else {
                            $(".sort_list_wrap li i").removeClass("active");
                            $sortIconObj.addClass("active");
                        }
                        var sortType = $sortIconObj.hasClass(settings._sortDescClass) ? "DESC" : "ASC";
                        settings.sort.onItemClick.call(this, $(this).attr("data_key"), sortType);
                        //重置全选
                        $this.find(".lazy_table_checkall").prop("checked", false);
                        //如果复选框美化过,则刷新美化过复选框
                        if ($.type($.fn.iCheck) === "function") {
                            $this.find(".lazy_table_checkall").iCheck("update");
                        }
                    }
                });
                //操作按钮
                if (settings.buttons.showTrigger == "colorBlock" || settings.buttons.showTrigger == "both") {
                    $this.on({
                        mouseenter: function() {
                            var bgColor = $(this).find(".color_block").css("background-color");
                            $(this).parent().find(".buttons_wrap").css("background-color", bgColor).show();
                        },
                        mouseleave: function() {
                            $(this).parent().find(".buttons_wrap").hide();
                        }
                    }, ".button_wrap_td");
                }
                if (settings.buttons.showTrigger == "row" || settings.buttons.showTrigger == "both") {
                    $this.on({
                        mouseenter: function() {
                            var $buttonWrapObj = $(this).find(".buttons_wrap");
                            if (settings.buttons.showTrigger == "both") {
                                var bgColor = $(this).find(".color_block").css("background-color");
                                $buttonWrapObj.css("background-color", bgColor);
                            }
                            $buttonWrapObj.show();
                        },
                        mouseleave: function() {
                            $(this).find(".buttons_wrap").hide();
                        }
                    }, ".lazy_table_tbody tr");
                }
                //按钮
                $this.on({
                    click: function() {
                        var dataKey = $(this).attr("data_key");
                        settings.buttons.buttonInfor[dataKey].func.call(this, $(this).parents(".lazy_table_tr").data("data"));
                        return false;
                    }
                }, ".buttons_wrap .lazy_table_button");
                //批量操作
                $this.on({
                    click: function() {
                        var dataKey = $(this).attr("data_key");
                        //获取选中的行
                        var checkedTrData = methods.getSelectedItems.call($this);
                        settings.batchButtons[dataKey].func.call(this, checkedTrData);
                    }
                }, ".batch_button");
                //自动美化复选框  需要分离
                if ($.fn.iCheck) {
                    $this.on('ifChanged', '.lazy_table_checkall', function(event) {
                        $this.find(".lazy_table_checkbox,.lazy_table_checkall").prop("checked", $(this).prop("checked")).iCheck('update');
                    });
                    $this.on('ifChanged', '.lazy_table_checkbox', function(event) {
                        if ($(this).prop("checked")) {
                            if ($this.find(".lazy_table_checkbox").filter(function() {
                                return $(this).prop("checked") == false;
                            }).length == 0) {
                                $this.find(".lazy_table_checkall").prop("checked", true);
                            }
                        } else {
                            $this.find(".lazy_table_checkall").prop("checked", false);
                        }
                        $this.find(":checkbox").iCheck('update');
                    });
                } else {
                    $this.find(".lazy_table_checkall").click(function() {
                        $this.find(".lazy_table_checkbox,.lazy_table_checkall").prop("checked", $(this).prop("checked"));
                    });
                    $this.on({
                        click: function() {
                            if ($(this).prop("checked")) {
                                if ($this.find(".lazy_table_checkbox").filter(function() {
                                    return $(this).prop("checked") == false;
                                }).length == 0) {
                                    $this.find(".lazy_table_checkall").prop("checked", true);
                                }
                            } else {
                                $this.find(".lazy_table_checkall").prop("checked", false);
                            }
                        }
                    }, ".lazy_table_checkbox");
                }
                methods._loadData.call(this);
            });
        },
        /*
         * 重新加载列表数据
         */
        reload: function(param, doNotResetParam) {
            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyTableSettings"),
                    originalParam = $this.data("lazyTableParam");
                //重置参数
                if (!doNotResetParam) {
                    settings.param = originalParam;
                }
                $this.data("lazyTableSettings", $.extend(true, {}, settings, param));
                methods._loadData.call(this);
            });
        },
        /*
         * 隐藏字段
         * @param fields  隐藏的字段 {array} ["field1","field2","field3"]
         * 如果有参数则隐藏参数中的字段，否则隐藏配置中autoHide的列
         */
        hideFields: function(fields) {
            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyTableSettings"),
                    hideFields;
                if (fields) {
                    hideFields = fields
                } else {
                    var temp = [];
                    $.each(settings.column, function(index, value) {
                        if (value.autoHide) {
                            temp.push(value.key);
                        }
                    });
                    hideFields = temp;
                }
                $.each(hideFields, function(index, value) {
                    $this.find('td[data-column="' + value + '"]').hide();
                });
                $this.data("hideFields", true);
            });
        },
        /*
         * 显示字段
         */
        showFields: function(fields) {
            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyTableSettings"),
                    showFields;
                if (fields) {
                    showFields = fields
                } else {
                    var temp = [];
                    $.each(settings.column, function(index, value) {
                        if (value.autoHide) {
                            temp.push(value.key);
                        }
                    });
                    showFields = temp;
                }
                $.each(showFields, function(index, value) {
                    $this.find('td[data-column="' + value + '"]').show();
                });
                $this.removeData("hideFields");
            });
        },
        /**
         * 获取选中的项
         * @return {[type]} [description]
         */
        getSelectedItems: function() {
            var checkedTrData = [];
            $(this).find(".lazy_table_tr").filter(function() {
                return $(this).find("td[data-column='checkall'] :checkbox").prop("checked");
            }).each(function() {
                checkedTrData.push($(this).data("data"));
            });
            return checkedTrData;
        },
        /*
         * 创建表头
         */
        _createHeaderHtml: function() {
            var $this = $(this),
                settings = $this.data("lazyTableSettings");
            var headerHtml = ['<thead class="lazy_table_thead"><tr>'];
            $.each(settings.column, function(index, value) {
                headerHtml.push('<td');
                if (value.key == "checkall") {
                    headerHtml.push(" style='width:40px;'");
                }
                headerHtml.push(' data-column="' + value.key + '">');
                //全选
                if (value.key == "checkall") {
                    headerHtml.push('<input type="checkbox" class="lazy_table_checkall checkbox"/>');
                } else {
                    headerHtml.push(value.title);
                }
                headerHtml.push('</td>');
            });
            //排序
            headerHtml.push('<td class="sort_title_td">');
            if (settings.sort) {
                headerHtml.push('<div class="sort_title_wrap"><span class="title">'+LazypluginsArgu.LazypluginsOrderBY+'</span><i class="fa ' + settings._sortDescClass + '"></i></div>');
                headerHtml.push('<ul class="sort_list_wrap">');
                $.each(settings.sort.items, function(index, value) {
                    headerHtml.push('<li title="' + value.title + '" class="ellipsis_field" data_key="' + value.key + '">');
                    headerHtml.push('<i class="fa ');
                    //默认排序
                    if (value.isDefault) {
                        headerHtml.push('active');
                    }
                    var sortTypeClass = value.type && value.type.toUpperCase() == "ASC" ? settings._sortAscClass : settings._sortDescClass;
                    headerHtml.push(' ' + sortTypeClass);
                    headerHtml.push('"></i> ');
                    headerHtml.push('<span class="title">' + value.title + '</span>');
                    headerHtml.push('</li>');
                });
                headerHtml.push('</ul>');
            }
            headerHtml.push('</td>');
            headerHtml.push('</tr></thead>');
            return headerHtml.join('');
        },
        /*
         * 加载数据
         */
        _loadData: function() {
            var $this = $(this),
                settings = $this.data("lazyTableSettings");
            $this.find(".lazy_table_loading").data("load", true);
            $.extend(settings.param, {
                currentPage: settings.page.currentPage,
                itemsPerPage: settings.page.itemsPerPage
            });
            $this.find(".empty_tip,.lazy_table_bottom").hide();
            $.ajax({
                url: settings.dataSource,
                type: 'POST',
                data: settings.param
            }).done(function(result) {


                if (result) {
                    var parsedData = $.parseJSON(result);
                    if (parsedData.totalCount == 0) {
                        $this.find(".empty_tip").show();
                        $this.find(".lazy_table_table,.lazy_table_bottom,.lazy_table_loading").hide();
                    } else {
                        $this.find(".empty_tip").hide();
                        $this.find(".lazy_table_table,.lazy_table_bottom").show();
                        //分页
                        if (settings.page) {
                            var $pageObj = $this.find(".pagination_wrap"),
                                totalPage = Math.ceil(parsedData.totalCount / settings.page.itemsPerPage),
                                parsedCount = parseInt(settings.page.currentPage),
                                currentPage = parsedCount < totalPage ? parsedCount + 1 : totalPage;
                            $pageObj.find(".total-count").html(parsedData.totalCount);
                            if ($pageObj.hasClass("pagination")) {
                                $pageObj.addClass("pagination").jqPagination("destroy");
                            }
                            $pageObj.addClass("pagination").jqPagination({
                                current_page: currentPage,
                                max_page: totalPage,
                                page_string: '{current_page}/{max_page}',
                                paged: function(page) {
                                    $this.LazyTable("reload", {
                                        page: {
                                            currentPage: page - 1
                                        }
                                    }, true);
                                },
                                onChangePageCount: function(pageCount) {
                                    $this.LazyTable("reload", {
                                        page: {
                                            itemsPerPage: pageCount,
                                            currentPage: 0
                                        }
                                    }, true);
                                }
                            });
                            //}
                        }
                        //清空旧数据
                        $this.find("tbody.lazy_table_tbody").html('');
                        $.each(parsedData.list, function(index, value) {
                            var trHtml = [];
                            $.each(settings.column, function(columnIndex, columnValue) {
                                trHtml.push('<td');
                                if (columnValue.key == "checkall") {
                                    trHtml.push(" style='width:40px;'");
                                }
                                trHtml.push(' data-column="' + columnValue.key + '">');
                                //全选
                                if (columnValue.key == "checkall") {
                                    if (!columnValue.showCheckAll || (columnValue.showCheckAll && columnValue.showCheckAll(value))) {
                                        trHtml.push('<input type="checkbox" class="lazy_table_checkbox checkbox"/>');
                                    }
                                } else {
                                    //如果定义了模板，则忽略宽度
                                    if (columnValue.template) {
                                        trHtml.push($.LazyFormatTemplate(columnValue.template, value));
                                    } else {
                                        //固定列宽
                                        if (columnValue.width) {
                                            var width = $.type(columnValue.width) === "number" ? columnValue.width + "px" : columnValue.width;
                                            trHtml.push('<div title="' + value[columnValue.key] + '" class="ellipsis_field" style="width:' + width + '">');
                                            trHtml.push(value[columnValue.key]);
                                            trHtml.push('</div>');
                                        } else {
                                            trHtml.push(value[columnValue.key]);
                                        }
                                    }
                                }
                                trHtml.push('</td>');
                            });
                            //默认按钮
                            var defaultButton;
                            if (settings.buttons.buttonInfor) {
                                trHtml.push('<td class="button_wrap_td">');
                                if (settings.buttons.showTrigger == "colorBlock" || settings.buttons.showTrigger == "both") {
                                    trHtml.push('<span class="color_block" style="background-color:' + settings._colors[parseInt(Math.random() * settings._colors.length)] + ';"></span>');
                                }
                                var buttonsFilter = [];
                                if (settings.buttons.filter) {
                                    buttonsFilter = settings.buttons.filter(value);
                                } else {
                                    //默认具有所有按钮权限
                                    $.each(settings.buttons.buttonInfor, function(buttonIndex, buttonValue) {
                                        buttonsFilter.push(buttonIndex);
                                    });
                                }
                                var myIndex = settings.hideHeader ? index : index + 1;
                                var buttonHtml = [];
                                //计算宽度,此处暂时无法自动适应宽度,先进行计算
                                var buttonWrapWidth = 0;
                                $.each(buttonsFilter, function(buttonIndex, buttonValue) {
                                    var buttonTitle = settings.buttons.buttonInfor[buttonValue].title;
                                    if (buttonTitle) {
                                        var buttonWidth = $.LazyGetStringLength(buttonTitle) * 8;
                                        buttonHtml.push('<a href="#" style="width:' + buttonWidth + 'px;" class="lazy_table_button ignore-link" data_key="' + buttonValue + '">');
                                        buttonHtml.push(buttonTitle);
                                        buttonHtml.push('</a>');
                                        buttonWrapWidth += buttonWidth;
                                    }
                                    if (settings.buttons.buttonInfor[buttonValue].isDefault) {
                                        defaultButton = settings.buttons.buttonInfor[buttonValue];
                                    }
                                });
                                trHtml.push('<div style="position:relative;"><div class="buttons_wrap" style="width:' + buttonWrapWidth + 'px;" >');
                                trHtml.push(buttonHtml.join(''));
                                trHtml.push('</div></div>');
                                trHtml.push('</td>');
                            }
                            var startX = -1;
                            var xoffset = 100;
                            var $trObj = $('<tr/>', {
                                'class': 'lazy_table_tr'
                            }).data("data", value).html(trHtml.join('')).click(function(event) {
                                if (defaultButton && !$(event.target).hasClass("ignore-link")) {
                                    defaultButton.func.call(this, value);
                                }
                            });
                            $this.find("tbody.lazy_table_tbody").append($trObj);
                        });
                        if ($this.data("hideFields")) {
                            $this.LazyTable("hideFields");
                        }
                        if (settings.onAfterLoad) {
                            settings.onAfterLoad.call(this, parsedData);
                        }
                        if ($.fn.iCheck) {
                            $this.find(':checkbox').iCheck({
                                checkboxClass: 'icheckbox_square-grey'
                            });
                            $this.find(':checkbox.lazy_table_checkall').iCheck({
                                checkboxClass: 'icheckbox_square-blue'
                            });
                        }
                    }
                    if (settings.onAfterLoad) {
                        settings.onAfterLoad.call(this, parsedData);
                    }
                } else {
                    if (settings.hideHeaderWhenEmpty) {
                        $this.find(".lazy_table_table").hide();
                    }
                }
            });
        },
        /*
         * 获取当前页码
         */
        getCurrentPage: function() {
            return $(this).find(".pagination_wrap").jqPagination("option", "current_page");
        }
    };
    $.fn.LazyTable = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazyTable');
        }
    };
})(jQuery);
/*
 * 列表插件
 */
(function($) {
    var methods = {
        init: function(options) {
            return this.each(function() {
                var $this = $(this);
                //默认参数
                var settings = $.extend(true, {
                    width: 300, //宽度
                    param: {}, //参数，当dataSource为Url时有效
                    mode: "single", //muli-多选
                    /*
                     * 数据源 支持url和数组格式  没有title时 可直接返回item对象
                     * [{
                     *  title:"",
                     * item:[{
                     *  itemTitle:{},
                     *  itemList:[{},{}]
                     * }]
                     *
                     * }]
                     */
                    dataSource: false,
                    /*
                     * 列表操作按钮
                     *
                     * buttons : {
                     *
                     * //定义所有需要使用的按钮信息
                     buttonInfor : {

                     //按钮key 用于标识按钮
                     "handler" : {
                     title : "办理", //按钮名称
                     func : function(data) { //按钮点击回调函数 data为 dataSource的数据结构

                     }
                     }
                     },

                     //筛选需要出现的按钮，用于根据权限显示不同按钮
                     //默认是全部按钮都显示
                     filter : function(data) {
                     if (data && data.priv) {
                     if (data.priv == "1") {
                     return ["delete", "view"];   //需返回按钮的key的数组
                     } else if (data.priv == "2") {
                     return ["download", "entrust"];
                     }
                     }
                     }
                     }
                     */
                    buttons: false,
                    //数据中的唯一标识字段
                    dataKey: 'id',
                    //唯一标识值
                    defaultKey: false,
                    itemTitleStyle: {},
                    itemTitleTemplate: false, //分类名称模版
                    itemListTemplate: false, //具体类项模版  模版支持  string|function
                    //回调函数
                    onItemMouseEnter: $.noop, //item mouseenter 事件
                    onItemMouseLeave: $.noop, //item mouseleave 事件
                    onItemClick: $.noop, //item click 事件 (ui,data) ui整个列表容器，可通过此获得任意元素， data item的数据， 格式为dataSource返回的对象
                    onItemTitleClick: false,
                    onInit: $.noop
                }, options);
                var $itemListWrap = $("<ul/>", {
                    'class': 'item_list_wrap'
                });
                $this.data({
                    lazyListSettings: settings,
                    lazyListParam: settings.param
                }).addClass("lazy_list_wrap").width(settings.width).html($itemListWrap);
                //获取数据
                if ($.type(settings.dataSource) === "string") {
                    methods._loadAjaxData.call(this);
                } else {
                    methods._loadData.call(this, settings.dataSource);
                }
                $this.off( "click", "li.list").on({
                    mouseenter: function() {
                        $(this).find(".buttons_wrap").show();
                        if ($(this).hasClass("current")) return false;
                        $(this).addClass("hover");
                        settings.onItemMouseEnter.call(this);
                    },
                    mouseleave: function() {
                        $(this).find(".buttons_wrap").hide();
                        if ($(this).hasClass("current")) return false;
                        $(this).removeClass("hover");
                        settings.onItemMouseLeave.call(this);
                    },
                    click: function(event) {
                        if (settings.mode == "single") {
                            $this.find("li.list,li.title").removeClass("hover current");
                            $(this).addClass("current");
                            settings.onItemClick.call(this, $(this).parents(".lazy_list_wrap"), $(this).data("data"), event, $(this));
                        } else {
                            if ($(this).find(".remark").length == 1) {
                                $(this).find(".remark").remove();
                            } else {
                                $(this).append('<i class="fa fa-check-circle remark"></i>');
                            }
                        }
                        return false;
                    }
                }, "li.list");
                if (settings.onItemTitleClick) {
                    $this.on({
                        mouseenter: function() {
                            if ($(this).hasClass("current")) return false;
                            $(this).addClass("hover");
                        },
                        mouseleave: function() {
                            if ($(this).hasClass("current")) return false;
                            $(this).removeClass("hover");
                        },
                        click: function(event) {
                            $this.find("li.list,li.title").removeClass("hover current");
                            $(this).addClass("current");
                            settings.onItemTitleClick.call(this, $(this).parents(".lazy_list_wrap"), $(this).data("data"), event, $(this));
                            return false;
                        }
                    }, "li.title");
                }
                $this.on({
                    click: function() {
                        var dataKey = $(this).attr("data_key");
                        settings.buttons.buttonInfor[dataKey].func.call(this, $(this).parents("li.list").data("data"));
                        return false;
                    }
                }, ".buttons_wrap a");
            });
        },
        // reload: function(param) {
        //     return this.each(function() {
        //         var $this = $(this),
        //             settings = $this.data("lazyListSettings");
        //         $.extend(settings, param);
        //         methods._loadAjaxData.call(this);
        //     });
        // },
        reload: function(param, doNotResetParam) {
            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyListSettings"),
                    originalParam = $this.data("lazyListParam");
                //重置参数
                if (!doNotResetParam) {
                    settings.param = originalParam;
                }
                $this.data("lazyListSettings", $.extend(true, {}, settings, param));
                methods._loadAjaxData.call(this);
            });
        },
        /**
         * 选中列表项
         * @param  {[type]} dataKey       [主键值,需要指定dataKey]
         * @param  {[type]} doNotTriggerClick [不夹在数据 默认会触发单击事件, 设为true 则只更新样式 不触发单击事件]
         * @return {[type]}               [description]
         */
        select: function(dataKey, doNotTriggerClick) {
            return this.each(function() {
                var $this = $(this),
                    settings = $this.data("lazyListSettings");
                //多选的初始化
                if (settings.mode == "muli") {
                    if (dataKey) {
                        var datatKeyArr = dataKey.split(",");
                        $.each(datatKeyArr, function(key, val) {
                            if (val) {
                                var $currentObj = $this.find("li.list[data_key=" + val + "]");
                                $currentObj.append('<i class="fa fa-check-circle remark"></i>');
                            }
                        });
                    }
                } else {
                    var $currentObj = $this.find("li.list[data_key=" + dataKey + "]");
                    if (doNotTriggerClick) {
                        $this.find("li.list,li.title").removeClass("hover current");
                        $currentObj.addClass("current");
                    } else {
                        $currentObj.click();
                    }
                }
            });
        },
        getSelectedItems: function() {
            var $this = $(this),
                settings = $this.data("lazyListSettings");
            var selectedItems = [];
            $this.find("li.list").filter(function() {
                return $(this).find(".remark").length == 1 || $(this).hasClass("current");
            }).each(function() {
                selectedItems.push($(this).data("data"));
            });
            return selectedItems;
        },
        /*
         * 加载ajax数据
         */
        _loadAjaxData: function() {
            var self = this,
                $this = $(this),
                settings = $this.data("lazyListSettings");
            $.ajax({
                url: settings.dataSource,
                data: settings.param
            }).done(function(result) {
                if (result) {
                    var parsedData = $.parseJSON(result);
                    methods._loadData.call(self, parsedData);
                } else {
                    alert("error");
                }
            }).fail(function() {
                alert("ajax error");
            });
        },
        /*
         * 加载列表数据
         */
        _loadData: function(dataSource) {
            var self = this,
                $this = $(this),
                settings = $this.data("lazyListSettings"),
                $itemListWrap = $this.find(".item_list_wrap");
            $itemListWrap.html("");
            var width = $.type(settings.width) === "number" ? settings.width + "px" : settings.width;
            $.each(dataSource, function(index, value) {
                //如果有lazySubItems表示是两级目录
                if (value.lazySubItems) {
                    var titleStr = $.LazyFormatTemplate(settings.itemTitleTemplate, value);
                    var titleText = titleStr.replace(/<\/?[^>]*>/g, '');
                    var $itemTitle = $("<li>", {
                        'class': "title",
                        'html': "<div title='" + titleText + "' style='width:100%;' class='ellipsis_field'>" + titleStr + '</div>'
                    }).data("data", value);
                    if (settings.itemTitleStyle) {
                        $itemTitle.css(settings.itemTitleStyle);
                    }
                    $itemListWrap.append($itemTitle);
                    var $subItemWrap = $("<ul/>", {
                        'class': 'sub_menu_wrap'
                    });
                    $.each(value.lazySubItems, function(subItemIndex, subItemValue) {
                        $subItemWrap.append(methods._createMenuItem.call(self, subItemValue, true));
                    });
                    $itemListWrap.append($("<li>").html($subItemWrap));
                } else {
                    var listStr = $.LazyFormatTemplate(settings.itemListTemplate, value);
                    var listText = listStr.replace(/<\/?[^>]*>/g, '');
                    $itemListWrap.append(methods._createMenuItem.call(self, value));
                }
            });
            settings.onInit.call(this);
        },
        _createMenuItem: function(listInfor, isInGroup) {
            var $this = $(this),
                settings = $this.data("lazyListSettings");
            var listStr = $.LazyFormatTemplate(settings.itemListTemplate, listInfor);
            var listText = listStr.replace(/<\/?[^>]*>/g, '');
            var $listObj = $("<li>", {
                'class': 'list',
                'data_key': listInfor[settings.dataKey],
                'html': "<div title='" + listText + "' style='width:100%;' class='ellipsis_field'>" + listStr + '</div>'
            }).data("data", listInfor).append(methods._createButtons.call($this, listInfor));
            if (isInGroup) {
                $listObj.addClass("in_group");
            }
            if (settings.mode == "muli") {
                if (settings.defaultKey) {
                    var defaultKey = settings.defaultKey;
                    defaultKey = "," + defaultKey + ",";
                    if (defaultKey.indexOf("," + listInfor[settings.dataKey] + ",") > -1) {
                        $listObj.append('<i class="fa fa-check-circle remark"></i>');
                    }
                }
            } else {
                if (settings.defaultKey && settings.defaultKey == listInfor[settings.dataKey]) {
                    $listObj.addClass("current");
                }
            }
            return $listObj;
        },
        _createButtons: function(dataInfor) {
            var $this = $(this),
                settings = $this.data("lazyListSettings"),
                buttons = settings.buttons;
            if (!buttons) {
                return "";
            }
            var buttonsFilter = [];
            //获取按钮权限
            if (buttons.filter) {
                buttonsFilter = buttons.filter(dataInfor);
            } else {
                //默认具有所有按钮权限
                $.each(buttons.buttonInfor, function(buttonIndex, buttonValue) {
                    buttonsFilter.push(buttonIndex);
                });
            }
            var buttonsHtml = ['<div class="buttons_wrap">'];
            $.each(buttonsFilter, function(buttonIndex, buttonValue) {
                buttonsHtml.push('<a href="#" data_key="' + buttonValue + '">');
                buttonsHtml.push(buttons.buttonInfor[buttonValue].title);
                buttonsHtml.push('</a>');
            });
            buttonsHtml.push('</div>');
            return buttonsHtml.join('');
        }
    };
    $.fn.LazyList = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazyList');
        }
    };
})(jQuery);
/*
 * 查询插件
 */
(function($) {
    var methods = {
        init: function(options) {
            return this.each(function() {
                var self = this,
                    $this = $(this);
                //默认参数
                var settings = $.extend(true, {
                    tip: "Search", //查询框提示文字
                    width: 200, //查询框宽度
                    height: 27, //查询框高度
                    url: "do.php", //数据处理页地址
                    param: {}, //参数
                    appendTo: "body", //元素附加元素
                    mode: "mini", //模式 full/mini-默认不显示输入框
                    /*
                     * 自动查询
                     * 参数定义示例
                     * autoSearch : {
                     *      template : "{flowName}",   //下拉数据模版
                     *      //点击item回调函数  data为定义item是的数据结构
                     *      onItemClick : function(data) {
                     *      }
                     *  }
                     */
                    autoSerch: false,
                    /*
                     * 字段查询
                     *
                     * //数组 每项定义key 和 title
                     * fieldSearch : {
                     onItemClick : function(data) {

                     },
                     items : [{
                     key : "flowNumber",
                     title : "流水号包含"
                     }, {
                     key : "flowTitle",
                     title : "流程标题包含"
                     }]
                     }
                     */
                    fieldSearch: false,
                    /*
                     * 高级查询
                     * advancedSearch : {
                     onSearch : function(data) {

                     },
                     items : [{
                     key : "fromName", //查询字段key
                     title : "发件人",//查询字段展示名称
                     type : "text"//类型
                     }, {
                     key : "folder",
                     title : "文件夹",
                     type : "select",
                     dataList : [{
                     key : "all",
                     title : "全部"
                     }, {
                     key : "send",
                     title : "发件箱"
                     }, {
                     key : "receive",
                     title : "收件箱"
                     }]
                     }]

                     类型说明
                     text-文本框
                     select-下拉框,需要额外定义dataList参数 格式为 [{
                     key : "",
                     title : ""
                     }]
                     chooseUser-人员选择框
                     chooseDept-部门选择框
                     }
                     */
                    advancedSearch: false,
                    //查询按钮点击回调函数
                    onSearchButtonClick: $.noop,
                    //清除内容按钮点击回调函数
                    onClearButtonClick: $.noop,
                    //创建完成后回调函数
                    onCreate: $.noop
                }, options);
                $this.width(settings.width).data("lazySearchSettngs", settings).addClass("lazy_search").height(settings.height);
                //查询按钮
                var $searchIconButton = $("<a/>", {
                    'href': "#",
                    'html': '<i class="fa fa-search icon" style="line-height:' + settings.height + 'px;"></i>'
                }).click(function() {
                    if ($(this).find("i").hasClass("fa-search")) {
                        settings.onSearchButtonClick.call(this, $searchInput.val() == settings.tip ? "" : $searchInput.val());
                    } else if ($(this).find("i").hasClass("fa-times-circle")) {
                        methods.resetAutoSearch.call($this);
                        settings.onClearButtonClick.call(this);
                    }
                    return false;
                });
                //查询框
                var $searchInput = $("<input/>", {
                    type: "text",
                    tip: settings.tip,
                    value: settings.tip
                }).css({
                    width: (settings.width - 22) + "px" //chrome和firefox下 用  width直接赋值  值不一样
                }).height(settings.height).click(function() {
                    var value = $.trim($(this).val());
                    var tip = $(this).attr("tip");
                    if (value == tip) {
                        $(this).val("");
                        $(this).addClass("active");
                    }
                    if (settings.advancedSearch || ((settings.fieldSearch || settings.autoSearch) && $(this).val() != "")) {
                        $lazySearchResultWrap.show().offset({
                            top: $this.offset().top + $this.height() + 1
                        });
                        $(document).on("click.lazy_search", function(event) {
                            if (event.target == $searchInput.get(0)) {
                                return false;
                            }
                            $lazySearchResultWrap.hide();
                            if (settings.mode == "mini" && $(this).val() == settings.tip) {
                                $this.removeClass("active");
                            }
                        });
                    }
                }).focusout(function() {
                    var value = $.trim($(this).val());
                    var tip = $(this).attr("tip");
                    if (value == "") {
                        $(this).val(tip);
                        $(this).removeClass("active");
                    }
                }).keyup(function(event) {
                    //回车触发查询
                    if (event.keyCode == 13) {
                        //触发自动查询
                        if ($autoSearchWrap) {
                            methods._doAutoSearch.call(self, $.trim($(this).val()));
                        }
                        //触发字段查询的第一个字段
                        else if ($fieldSearchWrap && $fieldSearchWrap.find("li").length > 0) {
                            $fieldSearchWrap.find("li:first").click();
                        }
                    } else {
                        var thisValue = $.trim($(this).val());
                        if (thisValue == "") {
                            $searchIconButton.find('i').removeClass("fa-times-circle").addClass("fa-search");
                            if (settings.autoSearch) {
                                $autoSearchWrap.html("");
                            }
                            if (settings.advancedSearch) {
                                $lazySearchResultWrap.find(".split_wrap").hide();
                            }
                            if (settings.fieldSearch) {
                                $lazySearchResultWrap.find(".search_condition").hide();
                            }
                        } else {
                            //显示x
                            $searchIconButton.find("i").removeClass("fa-search").addClass("fa-times-circle");
                            if ((settings.fieldSearch || settings.autoSearch) && $lazySearchResultWrap.css("display") == "none") {
                                $lazySearchResultWrap.show().offset({
                                    left: $this.offset().left,
                                    top: $this.offset().top + $this.height()
                                });
                                $(document).on("click.lazy_search", function(event) {
                                    if (event.target == $searchInput.get(0)) {
                                        return false;
                                    }
                                    if (settings.mode == "mini") {
                                        $this.removeClass("active");
                                    }
                                    $lazySearchResultWrap.hide();
                                });
                            }
                            if (settings.autoSearch) {
                                methods._doAutoSearch.call(self, $.trim($(this).val()));
                            }
                            if (settings.advancedSearch) {
                                $lazySearchResultWrap.find(".split_wrap").show();
                            }
                            if (settings.fieldSearch) {
                                $lazySearchResultWrap.find(".search_condition").show().find(".value").html($(this).val());
                            }
                        }
                    }
                });
                if (settings.mode == "mini") {
                    $searchInput.css("opacity", 0);
                    $this.mouseenter(function(event) {
                        $(this).addClass("active").find(".icon").addClass("active");
                        $searchInput.animate({
                            opacity: 1
                        }, 100);
                    }).mouseleave(function(event) {
                        if (($searchInput.val() == "" || $searchInput.val() == settings.tip) && $lazySearchResultWrap) {
                            $lazySearchResultWrap.hide();
                            $(this).removeClass("active").find(".icon").removeClass("active");
                            $searchInput.animate({
                                opacity: 0
                            }, 100, function() {
                                $searchInput.blur();
                            });
                        }
                    });
                } else {
                    $this.addClass("active");
                }
                //生成查询框
                $this.html($searchInput).append($searchIconButton);
                if (settings.advancedSearch || settings.fieldSearch || settings.autoSearch) {
                    //查询结果容器
                    var $lazySearchResultWrap = $("<div/>", {
                        'class': "lazy_search_result_wrap",
                        'html': "<ul/>"
                    }).width(settings.width - 1);
                }
                //自动查询
                if (settings.autoSearch) {
                    var $autoSearchWrap = $("<ul/>", {
                        'class': 'auto_search_wrap'
                    });
                    $lazySearchResultWrap.append($autoSearchWrap);
                }
                //字段查询
                if (settings.fieldSearch) {
                    var $fieldSearchWrap = $("<ul/>", {
                        'class': 'field_search_wrap',
                        'html': ''
                    });
                    $.each(settings.fieldSearch.items, function(key, value) {
                        var $fieldSearchItem = $("<li/>", {
                            'class': 'search_condition',
                            'html': '<span class="title">' + value.title + '&nbsp;:&nbsp;</span><span class="value"></span>'
                        }).click(function() {
                            settings.fieldSearch.onItemClick.call(this, value, $searchInput.val() == settings.tip ? "" : $searchInput.val());
                        });
                        $fieldSearchWrap.append($fieldSearchItem);
                    });
                    $lazySearchResultWrap.append($fieldSearchWrap);
                }
                //高级查询
                if (settings.advancedSearch) {
                    //高级查询按钮
                    var $advancedSearchButton = $("<li/>", {
                        'class': "advanced_search",
                        'html': LazyPluginLang.LazySearch.advancedSearch
                    }).click(function() {
                        $lazySearchResultWrap.hide(100, function() {
                            $advancedSearchWrap.show(300);
                        });
                        return false;
                    });
                    var $advancedSearchButtonWrap = $("<ul/>", {
                        'class': 'advanced_search_button_wrap'
                    }).html('<li class="split_wrap"><div class="split"></div></li>').append($advancedSearchButton);
                    $lazySearchResultWrap.append($advancedSearchButtonWrap);
                    //高级搜索容器
                    var $advancedSearchWrap = $("<div/>", {
                        'class': 'advanced_search_wrap'
                    });
                    var itemType = $.type(settings.advancedSearch.items);
                    var formFieldHtml;
                    //数据源格式
                    if (itemType === "array") {
                        formFieldHtml = ['<table>'];
                        $.each(settings.advancedSearch.items, function(key, value) {
                            var typeHtml = "";
                            if (value.html) {
                                typeHtml = value.html;
                            } else {
                                switch (value.type) {
                                    case 'dateRange':
                                    case 'text':
                                    case 'date':
                                    case 'dateTime':
                                    case 'time':
                                        typeHtml = "<input type='text' key='" + value.key + "' data_type='" + value.type + "'/>";
                                        break;
                                    case 'select':
                                        if ($.type(value.dataList) === "string") {
                                            $.ajax({
                                                url: value.dataList,
                                                async: false
                                            }).done(function(result) {
                                                if (result) {
                                                    var parsedData = $.parseJSON(result);
                                                    typeHtml = "<select data-container='body' key='" + value.key + "'>" + methods._loadAdvancedSearchSelect.call(this, parsedData) + "</select>";
                                                }
                                            });
                                        } else {
                                            typeHtml = "<select data-container='body' key='" + value.key + "'>" + methods._loadAdvancedSearchSelect.call(this, value.dataList) + "</select>";
                                        }
                                        break;
                                }
                            }
                            if (key % 2 == 0) {
                                formFieldHtml.push('<tr><td class="title">' + value.title + '</td><td>' + typeHtml + '</td>');
                            } else {
                                formFieldHtml.push('<td class="title">' + value.title + '</td><td>' + typeHtml + '</td></tr>');
                            }
                        });
                        formFieldHtml.push('</table>');
                    }
                    var $bottonsWrap = $("<div>", {
                        'class': 'buttons_wrap'
                    });
                    //搜索按钮
                    var $searchButton = $("<button/>", {
                        'type': 'button',
                        'class': 'btn btn-primary',
                        'html': LazyPluginLang.LazySearch.search
                    }).click(function() {
                        //获取所有条件
                        var searchArray = {};
                        $advancedSearchWrap.find(":input").each(function() {
                            var key = $(this).attr("key");
                            var value = $(this).val();
                            searchArray[key] = value;
                        });
                        $lazySearchResultWrap.removeClass("active");
                        $searchIconButton.find(".icon").removeClass("active");
                        $advancedSearchWrap.hide(300);
                        methods.resetAutoSearch.call($this);
                        if (settings.advancedSearch.onSearch) {
                            settings.advancedSearch.onSearch.call(this, searchArray, $advancedSearchWrap);
                        }
                    });
                    //重置按钮
                    var $restButton = $("<button/>", {
                        'type': 'button',
                        'class': 'btn btn-default',
                        'html': EOlang.msgReset
                    }).click(function() {
                        methods.resetAdvancedSearch.call($this);
                    });
                    //关闭按钮
                    var $closeButton = $("<button/>", {
                        'type': 'button',
                        'class': 'btn btn-info',
                        'html': EOlang.msgClose
                    }).click(function() {
                        $lazySearchResultWrap.removeClass("active");
                        $searchIconButton.find(".icon").removeClass("active");
                        $advancedSearchWrap.hide(300);
                    });
                    $bottonsWrap.html($searchButton).append($restButton, $closeButton);
                    if (formFieldHtml) {
                        $advancedSearchWrap.html(formFieldHtml.join(''));
                        $advancedSearchWrap.append($bottonsWrap);
                    } else {
                        $advancedSearchWrap.load(settings.advancedSearch.items, function() {
                            $advancedSearchWrap.append($bottonsWrap);
                        });
                    }
                    $(settings.appendTo).append($advancedSearchWrap);
                    if ($.type($.fn.selectpicker) === "function") {
                        $advancedSearchWrap.find("select").selectpicker({
                            height: "24px",
                            width: "150px"
                        });
                    }
                }
                if ($lazySearchResultWrap) {
                    $this.append($lazySearchResultWrap);
                }
                settings.onCreate.call(this);
            });
        },
        /**
         * 重置高级查询的条件
         * @return {[type]} [description]
         */
        resetAdvancedSearch: function() {
            var $this = $(this),
                settings = $this.data("lazySearchSettngs"),
                $advancedSearchWrap = $(settings.appendTo).find(".advanced_search_wrap");
            $advancedSearchWrap.find(":text,input:hidden").val("");
            $advancedSearchWrap.find("select").each(function() {
                $(this).get(0).selectedIndex = 0;
            });
            if ($.type($.fn.selectpicker) === "function") {
                $advancedSearchWrap.find("select").selectpicker("refresh");
            }
            if (settings.advancedSearch.onAfterReset) {
                settings.advancedSearch.onAfterReset.call($advancedSearchWrap);
            }
        },
        /**
         * 重置自动查询
         * @return {[type]} [description]
         */
        resetAutoSearch: function() {
            var $this = $(this),
                $searchInput = $this.find(":text"),
                $searchIconButton = $this.find("a"),
                $lazySearchResultWrap = $this.find(".lazy_search_result_wrap");
            $searchInput.val($searchInput.attr("tip"));
            $searchIconButton.find("i").removeClass("fa-times-circle").addClass("fa-search");
            if ($lazySearchResultWrap) {
                $lazySearchResultWrap.find(".search_condition").hide().find(".value").html('');
                $lazySearchResultWrap.find(".split_wrap").hide();
                $lazySearchResultWrap.hide();
            }
        },
        /**
         * 销毁
         * @return {[type]} [description]
         */
        destroy: function() {
            var $this = $(this),
                settings = $this.data("lazySearchSettngs"),
                $advancedSearchWrap = $(settings.appendTo).find(".advanced_search_wrap");
            $this.removeClass("lazy_search active").html('');
            $this.removeData("lazySearchSettngs");
            $advancedSearchWrap.remove();
        },
        /*
         * 高级查询select的数据源支持url
         */
        _loadAdvancedSearchSelect: function(selectData) {
            var selectHtml = [];
            $.each(selectData, function(key, value) {
                selectHtml.push("<option value='" + value.key + "'>" + value.title + "</option>");
            });
            return selectHtml.join('');
        },
        /*
         * 自动查询
         */
        _doAutoSearch: function(inputValue) {
            var $this = $(this),
                settings = $this.data("lazySearchSettngs"),
                $autoSearchWrap = $this.find(".auto_search_wrap");
            var myParam = $.extend(true, settings.param, {
                lazySearch: inputValue
            });
            $.ajax({
                url: settings.url,
                data: myParam
            }).done(function(result) {
                $autoSearchWrap.html(String.format(LazyPluginLang.LazySearch.searchEmpty, inputValue));
                if (result) {
                    var parsedData = $.parseJSON(result);
                    $autoSearchWrap.html("");
                    $.each(parsedData, function(key, value) {
                        var htmlStr = $.LazyFormatTemplate(settings.autoSearch.template, value);
                        var titleStr = htmlStr.replace(/<\/?[^>]*>/g, '');
                        var $resultList = $("<li/>", {
                            html: htmlStr,
                            title: titleStr
                        }).click(function() {
                            settings.autoSearch.onItemClick.call(this, value);
                        });
                        $autoSearchWrap.append($resultList);
                    });
                }
            }).fail(function() {
                alert("ajax error");
            });
        }
    };
    $.fn.LazySearch = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazySearch');
        }
    };
})(jQuery);
/*
 * 提示信息插件
 * 依赖项 jquery ui - position
 */
(function($) {
    var methods = {
        init: function(options) {
            return this.each(function() {
                var $this = $(this);
                //默认参数
                var settings = $.extend({
                    //提示框显示、关闭的动画持续时间
                    showTime: 200,
                    //提示框保持的时候
                    holdTime: 1000,
                    //显示的位置相对于
                    ofTarget: "body"
                }, options);
                $this.data("lazyMessageSettings", settings).addClass("lazy_message").position({
                    of: settings.ofTarget,
                    my: "top",
                    at: "top"
                });
            });
        },
        /*
         * @param messageType success|infor|error|warning
         */
        open: function(messageContent, messageType) {
            this.each(function() {
                var $this = $(this);
                var settings = $this.data("lazyMessageSettings");
                $this.html(messageContent).removeClass("success error infor warning").addClass(messageType).slideDown(settings.showTime).delay(settings.holdTime).slideUp(settings.showTime);
            });
        }
    };
    $.fn.LazyMessage = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazyMessage');
        }
    };
})(jQuery);
/**
 * 分裂按钮
 */
(function($) {
    var methods = {
        init: function(options) {
            return this.each(function() {
                var $this = $(this);
                //默认参数
                var settings = $.extend({
                    //数据源
                    //格式[{key:"",title:""},{key:"",title:""}]
                    dataSource: false,
                    className: 'btn-primary',
                    //选中回调函数
                    onSelect: $.noop
                }, options);
                var defaultButton, dropdownList = [];
                $.each(settings.dataSource, function(index, value) {
                    if (value.isDefault) {
                        defaultButton = '<button type="button" class="btn ' + settings.className + ' split_button" data_key="' + value.key + '">' + value.title + '</button>';
                    } else {
                        dropdownList.push('<li class="split_button" data_key="' + value.key + '"><a href="#">' + value.title + '</a></li>');
                    }
                });
                $this.html('<div class="btn-group">' + defaultButton + '<button type="button" class="btn ' + settings.className + ' dropdown-toggle" data-toggle="dropdown"><span class="caret"></span></button><ul class="dropdown-menu">' + dropdownList.join('') + '</ul> </div>');
                $this.off('click').on({
                    click: function() {
                        settings.onSelect.call(this, $(this).attr("data_key"));
                        return false;
                    }
                }, ".split_button");
            });
        }
    };
    $.fn.LazySplitButton = function(method) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.LazySplitButton');
        }
    };
})(jQuery);
/*
 * jqPagination
 *
 */
(function($) {
    "use strict";
    $.jqPagination = function(el, options) {
        // To avoid scope issues, use 'base' instead of 'this'
        // to reference this class from internal events and functions.
        var base = this;
        // Access to jQuery and DOM versions of element
        base.$el = $(el);
        base.el = el;
        // get input jQuery object
        base.$input = base.$el.find('input');
        // Add a reverse reference to the DOM object
        base.$el.data("jqPagination", base);
        base.init = function() {
            base.options = $.extend({}, $.jqPagination.defaultOptions, options);
            // if the user hasn't provided a max page number in the options try and find
            // the data attribute for it, if that cannot be found, use one as a max page number
            if (base.options.max_page === null) {
                if (base.$input.data('max-page') !== undefined) {
                    base.options.max_page = base.$input.data('max-page');
                } else {
                    base.options.max_page = 1;
                }
            }
            // if the current-page data attribute is specified this takes priority
            // over the options passed in, so long as it's a number
            if (base.$input.data('current-page') !== undefined && base.isNumber(base.$input.data('current-page'))) {
                base.options.current_page = base.$input.data('current-page');
            }
            // remove the readonly attribute as JavaScript must be working by now ;-)
            base.$input.removeAttr('readonly');
            // set the initial input value
            // pass true to prevent paged callback form being fired
            base.updateInput(true);
            //***************
            // BIND EVENTS
            base.$input.on('focus.jqPagination mouseup.jqPagination', function(event) {
                // if event === focus, select all text...
                if (event.type === 'focus') {
                    var current_page = parseInt(base.options.current_page, 10);
                    $(this).val(current_page).select();
                    base.$el.find(".goto-button").animate({
                        width: 30
                    }, 200);
                }
                // if event === mouse up, return false. Fixes Chrome bug
                if (event.type === 'mouseup') {
                    return false;
                }
            });
            base.$input.on('blur.jqPagination keydown.jqPagination', function(event) {
                var $self = $(this),
                    current_page = parseInt(base.options.current_page, 10);
                // if the user hits escape revert the input back to the original value
                if (event.keyCode === 27) {
                    $self.val(current_page);
                    $self.blur();
                }
                // if the user hits enter, trigger blur event but DO NOT set the page value
                if (event.keyCode === 13) {
                    $self.blur();
                }
                // only set the page is the event is focusout.. aka blur
                if (event.type === 'blur') {
                    base.setPage($self.val(), $self.val() == current_page);
                    base.$el.find(".goto-button").animate({
                        width: 0
                    }, 200);
                }
            });
            base.$el.on('click.jqPagination', 'a', function(event) {
                var $self = $(this);
                // we don't want to do anything if we've clicked a disabled link
                // return false so we stop normal link action btu also drop out of this event
                if ($self.hasClass('disabled')) {
                    return false;
                }
                // for mac + windows (read: other), maintain the cmd + ctrl click for new tab
                if (!event.metaKey && !event.ctrlKey) {
                    event.preventDefault();
                    base.setPage($self.data('action'));
                }
            });
            base.$el.on('click.jqPagination', '.per-page-wrap', function() {
                var $pageCountListObj = base.$el.find("ul.page-count-list");
                if ($pageCountListObj.css("display") != "none") {
                    $pageCountListObj.hide();
                } else {
                    $pageCountListObj.show();
                }
                return false;
            });
            base.$el.on('click.jqPagination', 'ul.page-count-list li', function() {
                var pageCount = $(this).html();
                base.$el.find(".per-page-wrap .per-page").html(pageCount);
                base.options.onChangePageCount(pageCount);
                base.$el.find("ul.page-count-list").hide();
                return false;
            });
            $(document).on('click.jqPagination', function(event) {
                if (base.$el.find("ul.page-count-list").css('display') != 'none');
                base.$el.find("ul.page-count-list").hide();
            });
        };
        base.setPage = function(page, prevent_paged) {
            // return current_page value if getting instead of setting
            if (page === undefined) {
                return base.options.current_page;
            }
            var current_page = parseInt(base.options.current_page, 10),
                max_page = parseInt(base.options.max_page, 10);
            if (isNaN(parseInt(page, 10))) {
                switch (page) {
                    case 'first':
                        page = 1;
                        break;
                    case 'prev':
                    case 'previous':
                        page = current_page - 1;
                        break;
                    case 'next':
                        page = current_page + 1;
                        break;
                    case 'last':
                        page = max_page;
                        break;
                }
            }
            page = parseInt(page, 10);
            // reject any invalid page requests
            if (isNaN(page) || page < 1 || page > max_page) {
                // update the input element
                base.setInputValue(current_page);
                return false;
            }
            // update current page options
            base.options.current_page = page;
            base.$input.data('current-page', page);
            // update the input element
            base.updateInput(prevent_paged);
        };
        base.setMaxPage = function(max_page, prevent_paged) {
            // return the max_page value if getting instead of setting
            if (max_page === undefined) {
                return base.options.max_page;
            }
            // ignore if max_page is not a number
            if (!base.isNumber(max_page)) {
                console.error('jqPagination: max_page is not a number');
                return false;
            }
            // ignore if max_page is less than the current_page
            if (max_page < base.options.current_page) {
                console.error('jqPagination: max_page lower than current_page');
                return false;
            }
            // set max_page options
            base.options.max_page = max_page;
            base.$input.data('max-page', max_page);
            // update the input element
            base.updateInput(prevent_paged);
        };
        // ATTN this isn't really the correct name is it?
        base.updateInput = function(prevent_paged) {
            var current_page = parseInt(base.options.current_page, 10);
            // set the input value
            base.setInputValue(current_page);
            // set the link href attributes
            base.setLinks(current_page);
            // we may want to prevent the paged callback from being fired
            if (prevent_paged !== true) {
                // fire the callback function with the current page
                base.options.paged(current_page);
                return false;
            }
        };
        base.setInputValue = function(page) {
            var page_string = base.options.page_string,
                max_page = base.options.max_page;
            // this looks horrible :-(
            page_string = page_string.replace("{current_page}", page).replace("{max_page}", max_page);
            base.$input.val(page_string);
        };
        base.isNumber = function(n) {
            return !isNaN(parseFloat(n)) && isFinite(n);
        };
        base.setLinks = function(page) {
            var link_string = base.options.link_string,
                current_page = parseInt(base.options.current_page, 10),
                max_page = parseInt(base.options.max_page, 10);
            if (link_string !== '') {
                // set initial page numbers + make sure the page numbers aren't out of range
                var previous = current_page - 1;
                if (previous < 1) {
                    previous = 1;
                }
                var next = current_page + 1;
                if (next > max_page) {
                    next = max_page;
                }
                // apply each page number to the link string, set it back to the element href attribute
                base.$el.find('a.first').attr('href', link_string.replace('{page_number}', '1'));
                base.$el.find('a.prev, a.previous').attr('href', link_string.replace('{page_number}', previous));
                base.$el.find('a.next').attr('href', link_string.replace('{page_number}', next));
                base.$el.find('a.last').attr('href', link_string.replace('{page_number}', max_page));
            }
            // set disable class on appropriate links
            base.$el.find('a').removeClass('disabled');
            if (current_page === max_page) {
                base.$el.find('.next, .last').addClass('disabled');
            }
            if (current_page === 1) {
                base.$el.find('.previous, .first').addClass('disabled');
            }
        };
        base.callMethod = function(method, key, value) {
            switch (method.toLowerCase()) {
                case 'option':
                    // if we're getting, immediately return the value
                    if (value === undefined && typeof key !== "object") {
                        return base.options[key];
                    }
                    // set default object to trigger the paged event (legacy opperation)
                    var options = {
                        'trigger': true
                    },
                        result = false;
                    // if the key passed in is an object
                    if ($.isPlainObject(key) && !value) {
                        $.extend(options, key)
                    } else { // make the key value pair part of the default object
                        options[key] = value;
                    }
                    var prevent_paged = (options.trigger === false);
                    // if current_page property is set call setPage
                    if (options.current_page !== undefined) {
                        result = base.setPage(options.current_page, prevent_paged);
                    }
                    // if max_page property is set call setMaxPage
                    if (options.max_page !== undefined) {
                        result = base.setMaxPage(options.max_page, prevent_paged);
                    }
                    // if we've not got a result fire an error and return false
                    if (result === false) console.error('jqPagination: cannot get / set option ' + key);
                    return result;
                    break;
                case 'destroy':
                    base.$el.off('.jqPagination').find('*').off('.jqPagination');
                    base.$input.removeData();
                    break;
                default:
                    // the function name must not exist
                    console.error('jqPagination: method "' + method + '" does not exist');
                    return false;
            }
        };
        // Run initializer
        base.init();
    };
    $.jqPagination.defaultOptions = {
        current_page: 1,
        link_string: '',
        max_page: null,
        page_string: 'Page {current_page} of {max_page}',
        paged: function() {}
    };
    $.fn.jqPagination = function() {
        // get any function parameters
        var self = this,
            $self = $(self),
            args = Array.prototype.slice.call(arguments),
            result = false;
        // if the first argument is a string call the desired function
        // note: we can only do this to a single element, and not a collection of elements
        if (typeof args[0] === 'string') {
            // if we're getting, we can only get value for the first pagination element
            if (args[2] === undefined) {
                result = $self.first()&&$self.first().data('jqPagination')?$self.first().data('jqPagination').callMethod(args[0], args[1]):'';
            } else {
                // if we're setting, set values for all pagination elements
                $self.each(function() {
                    result = $(this).data('jqPagination').callMethod(args[0], args[1], args[2]);
                });
            }
            return result;
        }
        // if we're not dealing with a method, initialise plugin
        self.each(function() {
            (new $.jqPagination(this, args[0]));
        });
    };
})(jQuery);
// polyfill, provide a fallback if the console doesn't exist
if (!console) {
    var console = {},
        func = function() {
            return false;
        };
    console.log = func;
    console.info = func;
    console.warn = func;
    console.error = func;
}
String.format = function(src) {
    if (arguments.length == 0) return null;
    var args = Array.prototype.slice.call(arguments, 1);
    return src.replace(/\{(\d+)\}/g, function(m, i) {
        return args[i];
    });
};